package db_dealer
import (
	"encoding/xml"
    "log"
    "fmt"
	"strings"
	"strconv"
    "time"    // for datetimes

	"golang.org/x/net/context"

	"github.com/pkg/errors"
    "gopkg.in/rana/ora.v3"    // Oracle
	"github.com/tgulacsi/oracall/custom"	// custom.Date
)

var DebugLevel = uint(0)

// against "unused import" error
var _ ora.Ses
var _ context.Context
var _ custom.Date
var _ strconv.NumError
var _ time.Time
var _ strings.Reader
var _ xml.Name
var _ log.Logger
var _ = errors.Wrap
var _ = fmt.Printf

type OraSesPool interface {
	Get() (*ora.Ses, error)
	Put(*ora.Ses)
}

type oracallServer struct {
	OraSesPool
}

func NewServer(p OraSesPool) *oracallServer {
	return &oracallServer{OraSesPool: p}
}


const Db_dealer__utolso_mod__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  :1 := DB_dealer.utolso_mod();


END;
`

func (s *oracallServer) DbDealer_UtolsoMod(ctx context.Context, input *DbDealer_UtolsoMod_Input) (output *DbDealer_UtolsoMod_Output, err error) {
	params := make([]interface{}, 1)
	var x, v interface{}
	_, _ = x, v
	params[0] = output.Ret // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.utolso_mod()
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__utolso_mod__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_adatok_gfb__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.szerzodes_adatok_gfb(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_rendszam=>:5,
		p_bonusz=>:6,
		p_elozmeny_bizt_nev=>:7,
		p_elozmeny_igazolt=>:8,
		p_kotveny_uid=>:9,
		p_szerzodo_uid=>:10,
		p_ktny_hiba_kod=>:11,
		p_ktny_hiba_szov=>:12);


END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokGfb(ctx context.Context, input *DbDealer_SzerzodesAdatokGfb_Input) (output *DbDealer_SzerzodesAdatokGfb_Output, err error) {
	params := make([]interface{}, 12)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon            // gcs2
	params[1] = input.PSzerzAzon        // gcs2
	params[2] = output.PHibaKod         // gcs1
	params[3] = output.PHibaSzov        // gcs1
	params[4] = output.PRendszam        // gcs1
	params[5] = output.PBonusz          // gcs1
	params[6] = output.PElozmenyBiztNev // gcs1
	params[7] = output.PElozmenyIgazolt // gcs1
	params[8] = output.PKotvenyUid      // gcs1
	params[9] = output.PSzerzodoUid     // gcs1
	params[10] = output.PKtnyHibaKod    // gcs1
	params[11] = output.PKtnyHibaSzov   // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_gfb(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_rendszam=>:p_rendszam,
		p_bonusz=>:p_bonusz,
		p_elozmeny_bizt_nev=>:p_elozmeny_bizt_nev,
		p_elozmeny_igazolt=>:p_elozmeny_igazolt,
		p_kotveny_uid=>:p_kotveny_uid,
		p_szerzodo_uid=>:p_szerzodo_uid,
		p_ktny_hiba_kod=>:p_ktny_hiba_kod,
		p_ktny_hiba_szov=>:p_ktny_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_gfb__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_adatok_casco__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.ZARADEK_TAB_TYP;
  TYPE VARCHAR2_3_tab_typ IS TABLE OF VARCHAR2(3) INDEX BY BINARY_INTEGER;
  p002#tipus VARCHAR2_3_tab_typ;
  TYPE VARCHAR2_1000_tab_typ IS TABLE OF VARCHAR2(1000) INDEX BY BINARY_INTEGER;
  p002#szoveg VARCHAR2_1000_tab_typ;
  TYPE NUMBER_12_2_tab_typ IS TABLE OF NUMBER(12, 2) INDEX BY BINARY_INTEGER;
  p002#ertek1 NUMBER_12_2_tab_typ;
  p002#ertek2 NUMBER_12_2_tab_typ;
  v007 BRUNO.DB_DEALER_KOZOS.KEDVEZ_TAB_TYP;
  TYPE NUMBER_3_tab_typ IS TABLE OF NUMBER(3) INDEX BY BINARY_INTEGER;
  p008#szazalek NUMBER_3_tab_typ;
  TYPE VARCHAR2_6_tab_typ IS TABLE OF VARCHAR2(6) INDEX BY BINARY_INTEGER;
  p008#modkod VARCHAR2_6_tab_typ;
  TYPE VARCHAR2_40_tab_typ IS TABLE OF VARCHAR2(40) INDEX BY BINARY_INTEGER;
  p008#modnev VARCHAR2_40_tab_typ;
  v012 BRUNO.DB_DEALER.EXTRA_TAB_TYP;
  TYPE INTEGER_10_tab_typ IS TABLE OF INTEGER(10) INDEX BY BINARY_INTEGER;
  p013#kod INTEGER_10_tab_typ;
  p013#nev VARCHAR2_40_tab_typ;

BEGIN
  v001.DELETE;
  p002#tipus.DELETE;
  p002#szoveg.DELETE;
  p002#ertek1.DELETE;
  p002#ertek2.DELETE;
  v007.DELETE;
  p008#szazalek.DELETE;
  p008#modkod.DELETE;
  p008#modnev.DELETE;
  v012.DELETE;
  p013#kod.DELETE;
  p013#nev.DELETE;

  DB_dealer.szerzodes_adatok_casco(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_rendszam=>:5,
		p_gfb_bonusz=>:6,
		p_casco_bonusz=>:7,
		p_szemlezett=>:8,
		p_zaradekok=>v001,
		p_kedvezmenyek=>v007,
		p_extrak=>v012);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#tipus(i2) := v001(i1).tipus;
    p002#szoveg(i2) := v001(i1).szoveg;
    p002#ertek1(i2) := v001(i1).ertek1;
    p002#ertek2(i2) := v001(i1).ertek2;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :9 := p002#szoveg;
  :10 := p002#ertek1;
  :11 := p002#ertek2;
  :12 := p002#tipus;
  
  i1 := v007.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p008#modkod(i2) := v007(i1).modkod;
    p008#modnev(i2) := v007(i1).modnev;
    p008#szazalek(i2) := v007(i1).szazalek;
    i1 := v007.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :13 := p008#modnev;
  :14 := p008#szazalek;
  :15 := p008#modkod;
  
  i1 := v012.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p013#kod(i2) := v012(i1).kod;
    p013#nev(i2) := v012(i1).nev;
    i1 := v012.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :16 := p013#kod;
  :17 := p013#nev;

END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokCasco(ctx context.Context, input *DbDealer_SzerzodesAdatokCasco_Input) (output *DbDealer_SzerzodesAdatokCasco_Output, err error) {
	params := make([]interface{}, 17)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon        // gcs2
	params[1] = input.PSzerzAzon    // gcs2
	params[2] = output.PHibaKod     // gcs1
	params[3] = output.PHibaSzov    // gcs1
	params[4] = output.PRendszam    // gcs1
	params[5] = output.PGfbBonusz   // gcs1
	params[6] = output.PCascoBonusz // gcs1
	params[7] = output.PSzemlezett  // gcs1
	x__PZaradekok__Tipus := make([]string, 0, 1000)
	params[11] = x__PZaradekok__Tipus // gctr2
	x__PZaradekok__Szoveg := make([]string, 0, 1000)
	params[8] = x__PZaradekok__Szoveg // gctr2
	x__PZaradekok__Ertek1 := make([]float64, 0, 1000)
	params[9] = x__PZaradekok__Ertek1 // gctr2
	x__PZaradekok__Ertek2 := make([]float64, 0, 1000)
	params[10] = x__PZaradekok__Ertek2 // gctr2
	x__PKedvezmenyek__Modkod := make([]string, 0, 1000)
	params[14] = x__PKedvezmenyek__Modkod // gctr2
	x__PKedvezmenyek__Modnev := make([]string, 0, 1000)
	params[12] = x__PKedvezmenyek__Modnev // gctr2
	x__PKedvezmenyek__Szazalek := make([]float64, 0, 1000)
	params[13] = x__PKedvezmenyek__Szazalek // gctr2
	x__PExtrak__Kod := make([]int32, 0, 1000)
	params[15] = x__PExtrak__Kod // gctr2
	x__PExtrak__Nev := make([]string, 0, 1000)
	params[16] = x__PExtrak__Nev // gctr2

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_casco(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_rendszam=>:p_rendszam,
		p_gfb_bonusz=>:p_gfb_bonusz,
		p_casco_bonusz=>:p_casco_bonusz,
		p_szemlezett=>:p_szemlezett,
		p_zaradekok=>v001,
		p_kedvezmenyek=>v007,
		p_extrak=>v012)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_casco__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PZaradekok == nil { // *Db_dealer__zaradek_rec_typ__bruno
		output.PZaradekok = make([]*DbDealer_ZaradekRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PZaradekok__Tipus) - cap(output.PZaradekok); m > 0 {
		output.PZaradekok = append(output.PZaradekok, make([]*DbDealer_ZaradekRecTyp_Bruno, m)...)
	}
	output.PZaradekok = output.PZaradekok[:len(x__PZaradekok__Tipus)]
	for i, v := range x__PZaradekok__Tipus {
		if output.PZaradekok[i] != nil {
			output.PZaradekok[i].Tipus = v
		}
	}
	if m := len(x__PZaradekok__Szoveg) - cap(output.PZaradekok); m > 0 {
		output.PZaradekok = append(output.PZaradekok, make([]*DbDealer_ZaradekRecTyp_Bruno, m)...)
	}
	output.PZaradekok = output.PZaradekok[:len(x__PZaradekok__Szoveg)]
	for i, v := range x__PZaradekok__Szoveg {
		if output.PZaradekok[i] != nil {
			output.PZaradekok[i].Szoveg = v
		}
	}
	if m := len(x__PZaradekok__Ertek1) - cap(output.PZaradekok); m > 0 {
		output.PZaradekok = append(output.PZaradekok, make([]*DbDealer_ZaradekRecTyp_Bruno, m)...)
	}
	output.PZaradekok = output.PZaradekok[:len(x__PZaradekok__Ertek1)]
	for i, v := range x__PZaradekok__Ertek1 {
		if output.PZaradekok[i] != nil {
			output.PZaradekok[i].Ertek1 = v
		}
	}
	if m := len(x__PZaradekok__Ertek2) - cap(output.PZaradekok); m > 0 {
		output.PZaradekok = append(output.PZaradekok, make([]*DbDealer_ZaradekRecTyp_Bruno, m)...)
	}
	output.PZaradekok = output.PZaradekok[:len(x__PZaradekok__Ertek2)]
	for i, v := range x__PZaradekok__Ertek2 {
		if output.PZaradekok[i] != nil {
			output.PZaradekok[i].Ertek2 = v
		}
	}

	if output.PKedvezmenyek == nil { // *Db_dealer_kozos__kedvez_rec_typ__bruno
		output.PKedvezmenyek = make([]*DbDealerKozos_KedvezRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PKedvezmenyek__Modkod) - cap(output.PKedvezmenyek); m > 0 {
		output.PKedvezmenyek = append(output.PKedvezmenyek, make([]*DbDealerKozos_KedvezRecTyp_Bruno, m)...)
	}
	output.PKedvezmenyek = output.PKedvezmenyek[:len(x__PKedvezmenyek__Modkod)]
	for i, v := range x__PKedvezmenyek__Modkod {
		if output.PKedvezmenyek[i] != nil {
			output.PKedvezmenyek[i].Modkod = v
		}
	}
	if m := len(x__PKedvezmenyek__Modnev) - cap(output.PKedvezmenyek); m > 0 {
		output.PKedvezmenyek = append(output.PKedvezmenyek, make([]*DbDealerKozos_KedvezRecTyp_Bruno, m)...)
	}
	output.PKedvezmenyek = output.PKedvezmenyek[:len(x__PKedvezmenyek__Modnev)]
	for i, v := range x__PKedvezmenyek__Modnev {
		if output.PKedvezmenyek[i] != nil {
			output.PKedvezmenyek[i].Modnev = v
		}
	}
	if m := len(x__PKedvezmenyek__Szazalek) - cap(output.PKedvezmenyek); m > 0 {
		output.PKedvezmenyek = append(output.PKedvezmenyek, make([]*DbDealerKozos_KedvezRecTyp_Bruno, m)...)
	}
	output.PKedvezmenyek = output.PKedvezmenyek[:len(x__PKedvezmenyek__Szazalek)]
	for i, v := range x__PKedvezmenyek__Szazalek {
		if output.PKedvezmenyek[i] != nil {
			output.PKedvezmenyek[i].Szazalek = v
		}
	}

	if output.PExtrak == nil { // *Db_dealer__extra_rec_typ__bruno
		output.PExtrak = make([]*DbDealer_ExtraRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PExtrak__Kod) - cap(output.PExtrak); m > 0 {
		output.PExtrak = append(output.PExtrak, make([]*DbDealer_ExtraRecTyp_Bruno, m)...)
	}
	output.PExtrak = output.PExtrak[:len(x__PExtrak__Kod)]
	for i, v := range x__PExtrak__Kod {
		if output.PExtrak[i] != nil {
			output.PExtrak[i].Kod = v
		}
	}
	if m := len(x__PExtrak__Nev) - cap(output.PExtrak); m > 0 {
		output.PExtrak = append(output.PExtrak, make([]*DbDealer_ExtraRecTyp_Bruno, m)...)
	}
	output.PExtrak = output.PExtrak[:len(x__PExtrak__Nev)]
	for i, v := range x__PExtrak__Nev {
		if output.PExtrak[i] != nil {
			output.PExtrak[i].Nev = v
		}
	}

	return
}
const Db_dealer__szerzodes_adatok_onresz__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.szerzodes_adatok_onresz(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_rendszam=>:5,
		p_gfb_bonusz=>:6,
		p_casco_bonusz=>:7,
		p_alapbizt_bizt_kod=>:8,
		p_onresz_tip=>:9);


END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokOnresz(ctx context.Context, input *DbDealer_SzerzodesAdatokOnresz_Input) (output *DbDealer_SzerzodesAdatokOnresz_Output, err error) {
	params := make([]interface{}, 9)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon            // gcs2
	params[1] = input.PSzerzAzon        // gcs2
	params[2] = output.PHibaKod         // gcs1
	params[3] = output.PHibaSzov        // gcs1
	params[4] = output.PRendszam        // gcs1
	params[5] = output.PGfbBonusz       // gcs1
	params[6] = output.PCascoBonusz     // gcs1
	params[7] = output.PAlapbiztBiztKod // gcs1
	params[8] = output.POnreszTip       // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_onresz(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_rendszam=>:p_rendszam,
		p_gfb_bonusz=>:p_gfb_bonusz,
		p_casco_bonusz=>:p_casco_bonusz,
		p_alapbizt_bizt_kod=>:p_alapbizt_bizt_kod,
		p_onresz_tip=>:p_onresz_tip)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_onresz__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_adatok_otthon__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.ZARADEK_TAB_TYP;
  TYPE VARCHAR2_3_tab_typ IS TABLE OF VARCHAR2(3) INDEX BY BINARY_INTEGER;
  p002#tipus VARCHAR2_3_tab_typ;
  TYPE VARCHAR2_1000_tab_typ IS TABLE OF VARCHAR2(1000) INDEX BY BINARY_INTEGER;
  p002#szoveg VARCHAR2_1000_tab_typ;
  TYPE NUMBER_12_2_tab_typ IS TABLE OF NUMBER(12, 2) INDEX BY BINARY_INTEGER;
  p002#ertek1 NUMBER_12_2_tab_typ;
  p002#ertek2 NUMBER_12_2_tab_typ;
  v007 BRUNO.DB_DEALER_KOZOS.KEDVEZ_TAB_TYP;
  TYPE VARCHAR2_6_tab_typ IS TABLE OF VARCHAR2(6) INDEX BY BINARY_INTEGER;
  p008#modkod VARCHAR2_6_tab_typ;
  TYPE VARCHAR2_40_tab_typ IS TABLE OF VARCHAR2(40) INDEX BY BINARY_INTEGER;
  p008#modnev VARCHAR2_40_tab_typ;
  TYPE NUMBER_3_tab_typ IS TABLE OF NUMBER(3) INDEX BY BINARY_INTEGER;
  p008#szazalek NUMBER_3_tab_typ;

BEGIN
  v001.DELETE;
  p002#tipus.DELETE;
  p002#szoveg.DELETE;
  p002#ertek1.DELETE;
  p002#ertek2.DELETE;
  v007.DELETE;
  p008#modkod.DELETE;
  p008#modnev.DELETE;
  p008#szazalek.DELETE;

  DB_dealer.szerzodes_adatok_otthon(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_szemlezett=>:5,
		p_epulet_bo=>:6,
		p_epulet_ajanlott_ar=>:7,
		p_ingo_bo=>:8,
		p_ingo_ajanlott_ar=>:9,
		p_ertek_bo=>:10,
		p_vallalk_bo=>:11,
		p_baleset_egyseg=>:12,
		p_felelosseg_van=>:13,
		p_karmentes_szint=>:14,
		p_zaradekok=>v001,
		p_kedvezmenyek=>v007,
		p_kockhely_irszam=>:15,
		p_kockhely_ktid=>:16,
		p_kockhely_hazszam=>:17,
		p_kockhely_ajto=>:18);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#tipus(i2) := v001(i1).tipus;
    p002#szoveg(i2) := v001(i1).szoveg;
    p002#ertek1(i2) := v001(i1).ertek1;
    p002#ertek2(i2) := v001(i1).ertek2;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :19 := p002#ertek1;
  :20 := p002#ertek2;
  :21 := p002#tipus;
  :22 := p002#szoveg;
  
  i1 := v007.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p008#modkod(i2) := v007(i1).modkod;
    p008#modnev(i2) := v007(i1).modnev;
    p008#szazalek(i2) := v007(i1).szazalek;
    i1 := v007.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :23 := p008#modkod;
  :24 := p008#modnev;
  :25 := p008#szazalek;

END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokOtthon(ctx context.Context, input *DbDealer_SzerzodesAdatokOtthon_Input) (output *DbDealer_SzerzodesAdatokOtthon_Output, err error) {
	params := make([]interface{}, 25)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon             // gcs2
	params[1] = input.PSzerzAzon         // gcs2
	params[2] = output.PHibaKod          // gcs1
	params[3] = output.PHibaSzov         // gcs1
	params[4] = output.PSzemlezett       // gcs1
	params[5] = output.PEpuletBo         // gcs1
	params[6] = output.PEpuletAjanlottAr // gcs1
	params[7] = output.PIngoBo           // gcs1
	params[8] = output.PIngoAjanlottAr   // gcs1
	params[9] = output.PErtekBo          // gcs1
	params[10] = output.PVallalkBo       // gcs1
	params[11] = output.PBalesetEgyseg   // gcs1
	params[12] = output.PFelelossegVan   // gcs1
	params[13] = output.PKarmentesSzint  // gcs1
	x__PZaradekok__Tipus := make([]string, 0, 1000)
	params[20] = x__PZaradekok__Tipus // gctr2
	x__PZaradekok__Szoveg := make([]string, 0, 1000)
	params[21] = x__PZaradekok__Szoveg // gctr2
	x__PZaradekok__Ertek1 := make([]float64, 0, 1000)
	params[18] = x__PZaradekok__Ertek1 // gctr2
	x__PZaradekok__Ertek2 := make([]float64, 0, 1000)
	params[19] = x__PZaradekok__Ertek2 // gctr2
	x__PKedvezmenyek__Modkod := make([]string, 0, 1000)
	params[22] = x__PKedvezmenyek__Modkod // gctr2
	x__PKedvezmenyek__Modnev := make([]string, 0, 1000)
	params[23] = x__PKedvezmenyek__Modnev // gctr2
	x__PKedvezmenyek__Szazalek := make([]float64, 0, 1000)
	params[24] = x__PKedvezmenyek__Szazalek // gctr2
	params[14] = output.PKockhelyIrszam     // gcs1
	params[15] = output.PKockhelyKtid       // gcs1
	params[16] = output.PKockhelyHazszam    // gcs1
	params[17] = output.PKockhelyAjto       // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_otthon(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_szemlezett=>:p_szemlezett,
		p_epulet_bo=>:p_epulet_bo,
		p_epulet_ajanlott_ar=>:p_epulet_ajanlott_ar,
		p_ingo_bo=>:p_ingo_bo,
		p_ingo_ajanlott_ar=>:p_ingo_ajanlott_ar,
		p_ertek_bo=>:p_ertek_bo,
		p_vallalk_bo=>:p_vallalk_bo,
		p_baleset_egyseg=>:p_baleset_egyseg,
		p_felelosseg_van=>:p_felelosseg_van,
		p_karmentes_szint=>:p_karmentes_szint,
		p_zaradekok=>v001,
		p_kedvezmenyek=>v007,
		p_kockhely_irszam=>:p_kockhely_irszam,
		p_kockhely_ktid=>:p_kockhely_ktid,
		p_kockhely_hazszam=>:p_kockhely_hazszam,
		p_kockhely_ajto=>:p_kockhely_ajto)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_otthon__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PZaradekok == nil { // *Db_dealer__zaradek_rec_typ__bruno
		output.PZaradekok = make([]*DbDealer_ZaradekRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PZaradekok__Tipus) - cap(output.PZaradekok); m > 0 {
		output.PZaradekok = append(output.PZaradekok, make([]*DbDealer_ZaradekRecTyp_Bruno, m)...)
	}
	output.PZaradekok = output.PZaradekok[:len(x__PZaradekok__Tipus)]
	for i, v := range x__PZaradekok__Tipus {
		if output.PZaradekok[i] != nil {
			output.PZaradekok[i].Tipus = v
		}
	}
	if m := len(x__PZaradekok__Szoveg) - cap(output.PZaradekok); m > 0 {
		output.PZaradekok = append(output.PZaradekok, make([]*DbDealer_ZaradekRecTyp_Bruno, m)...)
	}
	output.PZaradekok = output.PZaradekok[:len(x__PZaradekok__Szoveg)]
	for i, v := range x__PZaradekok__Szoveg {
		if output.PZaradekok[i] != nil {
			output.PZaradekok[i].Szoveg = v
		}
	}
	if m := len(x__PZaradekok__Ertek1) - cap(output.PZaradekok); m > 0 {
		output.PZaradekok = append(output.PZaradekok, make([]*DbDealer_ZaradekRecTyp_Bruno, m)...)
	}
	output.PZaradekok = output.PZaradekok[:len(x__PZaradekok__Ertek1)]
	for i, v := range x__PZaradekok__Ertek1 {
		if output.PZaradekok[i] != nil {
			output.PZaradekok[i].Ertek1 = v
		}
	}
	if m := len(x__PZaradekok__Ertek2) - cap(output.PZaradekok); m > 0 {
		output.PZaradekok = append(output.PZaradekok, make([]*DbDealer_ZaradekRecTyp_Bruno, m)...)
	}
	output.PZaradekok = output.PZaradekok[:len(x__PZaradekok__Ertek2)]
	for i, v := range x__PZaradekok__Ertek2 {
		if output.PZaradekok[i] != nil {
			output.PZaradekok[i].Ertek2 = v
		}
	}

	if output.PKedvezmenyek == nil { // *Db_dealer_kozos__kedvez_rec_typ__bruno
		output.PKedvezmenyek = make([]*DbDealerKozos_KedvezRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PKedvezmenyek__Modkod) - cap(output.PKedvezmenyek); m > 0 {
		output.PKedvezmenyek = append(output.PKedvezmenyek, make([]*DbDealerKozos_KedvezRecTyp_Bruno, m)...)
	}
	output.PKedvezmenyek = output.PKedvezmenyek[:len(x__PKedvezmenyek__Modkod)]
	for i, v := range x__PKedvezmenyek__Modkod {
		if output.PKedvezmenyek[i] != nil {
			output.PKedvezmenyek[i].Modkod = v
		}
	}
	if m := len(x__PKedvezmenyek__Modnev) - cap(output.PKedvezmenyek); m > 0 {
		output.PKedvezmenyek = append(output.PKedvezmenyek, make([]*DbDealerKozos_KedvezRecTyp_Bruno, m)...)
	}
	output.PKedvezmenyek = output.PKedvezmenyek[:len(x__PKedvezmenyek__Modnev)]
	for i, v := range x__PKedvezmenyek__Modnev {
		if output.PKedvezmenyek[i] != nil {
			output.PKedvezmenyek[i].Modnev = v
		}
	}
	if m := len(x__PKedvezmenyek__Szazalek) - cap(output.PKedvezmenyek); m > 0 {
		output.PKedvezmenyek = append(output.PKedvezmenyek, make([]*DbDealerKozos_KedvezRecTyp_Bruno, m)...)
	}
	output.PKedvezmenyek = output.PKedvezmenyek[:len(x__PKedvezmenyek__Szazalek)]
	for i, v := range x__PKedvezmenyek__Szazalek {
		if output.PKedvezmenyek[i] != nil {
			output.PKedvezmenyek[i].Szazalek = v
		}
	}

	return
}
const Db_dealer__szerzodes_adatok_kaf__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.JARMUTIP_TAB_TYP;
  TYPE VARCHAR2_11_tab_typ IS TABLE OF VARCHAR2(11) INDEX BY BINARY_INTEGER;
  p002#rendszam VARCHAR2_11_tab_typ;
  TYPE VARCHAR2_80_tab_typ IS TABLE OF VARCHAR2(80) INDEX BY BINARY_INTEGER;
  p002#tipus VARCHAR2_80_tab_typ;

BEGIN
  v001.DELETE;
  p002#rendszam.DELETE;
  p002#tipus.DELETE;

  DB_dealer.szerzodes_adatok_kaf(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_jarmutip=>v001,
		p_biztossz=>:5,
		p_bo_penznem=>:6);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#rendszam(i2) := v001(i1).rendszam;
    p002#tipus(i2) := v001(i1).tipus;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :7 := p002#rendszam;
  :8 := p002#tipus;

END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokKaf(ctx context.Context, input *DbDealer_SzerzodesAdatokKaf_Input) (output *DbDealer_SzerzodesAdatokKaf_Output, err error) {
	params := make([]interface{}, 8)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	params[2] = output.PHibaKod  // gcs1
	params[3] = output.PHibaSzov // gcs1
	x__PJarmutip__Rendszam := make([]string, 0, 1000)
	params[6] = x__PJarmutip__Rendszam // gctr2
	x__PJarmutip__Tipus := make([]string, 0, 1000)
	params[7] = x__PJarmutip__Tipus // gctr2
	params[4] = output.PBiztossz    // gcs1
	params[5] = output.PBoPenznem   // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_kaf(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_jarmutip=>v001,
		p_biztossz=>:p_biztossz,
		p_bo_penznem=>:p_bo_penznem)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_kaf__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PJarmutip == nil { // *Db_dealer__jarmutip_rec_typ__bruno
		output.PJarmutip = make([]*DbDealer_JarmutipRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PJarmutip__Rendszam) - cap(output.PJarmutip); m > 0 {
		output.PJarmutip = append(output.PJarmutip, make([]*DbDealer_JarmutipRecTyp_Bruno, m)...)
	}
	output.PJarmutip = output.PJarmutip[:len(x__PJarmutip__Rendszam)]
	for i, v := range x__PJarmutip__Rendszam {
		if output.PJarmutip[i] != nil {
			output.PJarmutip[i].Rendszam = v
		}
	}
	if m := len(x__PJarmutip__Tipus) - cap(output.PJarmutip); m > 0 {
		output.PJarmutip = append(output.PJarmutip, make([]*DbDealer_JarmutipRecTyp_Bruno, m)...)
	}
	output.PJarmutip = output.PJarmutip[:len(x__PJarmutip__Tipus)]
	for i, v := range x__PJarmutip__Tipus {
		if output.PJarmutip[i] != nil {
			output.PJarmutip[i].Tipus = v
		}
	}

	return
}
const Db_dealer__busz_v_tgk__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  :1 := DB_dealer.busz_v_tgk(p_btkezd=>:2,
		p_kategoria2=>:3);


END;
`

func (s *oracallServer) DbDealer_BuszVTgk(ctx context.Context, input *DbDealer_BuszVTgk_Input) (output *DbDealer_BuszVTgk_Output, err error) {
	params := make([]interface{}, 3)
	var x, v interface{}
	_, _ = x, v
	params[1] = input.PBtkezd     // gcs2
	params[2] = input.PKategoria2 // gcs2
	params[0] = output.Ret        // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.busz_v_tgk(p_btkezd=>:p_btkezd,
		p_kategoria2=>:p_kategoria2)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__busz_v_tgk__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_adatok_kaf_igazolas__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.szerzodes_adatok_kaf_igazolas(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_serial_number=>:5,
		p_clientname=>:6,
		p_clientfirstname=>:7,
		p_pcode=>:8,
		p_city=>:9,
		p_streetname=>:10,
		p_streettype=>:11,
		p_streetno=>:12,
		p_streetfloor=>:13,
		p_contract_number=>:14,
		p_car_number=>:15,
		p_insurance_amount=>:16,
		p_insurance_begindate=>:17,
		p_insurance_amount_eur=>:18,
		p_date_insurance_covered=>:19,
		p_tax_number=>:20,
		p_category=>:21);


END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokKafIgazolas(ctx context.Context, input *DbDealer_SzerzodesAdatokKafIgazolas_Input) (output *DbDealer_SzerzodesAdatokKafIgazolas_Output, err error) {
	params := make([]interface{}, 21)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon                  // gcs2
	params[1] = input.PSzerzAzon              // gcs2
	params[2] = output.PHibaKod               // gcs1
	params[3] = output.PHibaSzov              // gcs1
	params[4] = output.PSerialNumber          // gcs1
	params[5] = output.PClientname            // gcs1
	params[6] = output.PClientfirstname       // gcs1
	params[7] = output.PPcode                 // gcs1
	params[8] = output.PCity                  // gcs1
	params[9] = output.PStreetname            // gcs1
	params[10] = output.PStreettype           // gcs1
	params[11] = output.PStreetno             // gcs1
	params[12] = output.PStreetfloor          // gcs1
	params[13] = output.PContractNumber       // gcs1
	params[14] = output.PCarNumber            // gcs1
	params[15] = output.PInsuranceAmount      // gcs1
	params[16] = output.PInsuranceBegindate   // gcs1
	params[17] = output.PInsuranceAmountEur   // gcs1
	params[18] = output.PDateInsuranceCovered // gcs1
	params[19] = output.PTaxNumber            // gcs1
	params[20] = output.PCategory             // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_kaf_igazolas(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_serial_number=>:p_serial_number,
		p_clientname=>:p_clientname,
		p_clientfirstname=>:p_clientfirstname,
		p_pcode=>:p_pcode,
		p_city=>:p_city,
		p_streetname=>:p_streetname,
		p_streettype=>:p_streettype,
		p_streetno=>:p_streetno,
		p_streetfloor=>:p_streetfloor,
		p_contract_number=>:p_contract_number,
		p_car_number=>:p_car_number,
		p_insurance_amount=>:p_insurance_amount,
		p_insurance_begindate=>:p_insurance_begindate,
		p_insurance_amount_eur=>:p_insurance_amount_eur,
		p_date_insurance_covered=>:p_date_insurance_covered,
		p_tax_number=>:p_tax_number,
		p_category=>:p_category)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_kaf_igazolas__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_adatok_faf__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.JARMUTIP_TAB_TYP;
  TYPE VARCHAR2_11_tab_typ IS TABLE OF VARCHAR2(11) INDEX BY BINARY_INTEGER;
  p002#rendszam VARCHAR2_11_tab_typ;
  TYPE VARCHAR2_80_tab_typ IS TABLE OF VARCHAR2(80) INDEX BY BINARY_INTEGER;
  p002#tipus VARCHAR2_80_tab_typ;
  v005 BRUNO.DB_DEALER.FAF_BIZTOSSZ_TAB_TYP;
  p006#rendszam VARCHAR2_11_tab_typ;
  TYPE NUMBER_12_2_tab_typ IS TABLE OF NUMBER(12, 2) INDEX BY BINARY_INTEGER;
  p006#limit NUMBER_12_2_tab_typ;
  p006#biztossz NUMBER_12_2_tab_typ;
  v010 BRUNO.DB_DEALER.POTD_KOCK_TAB_TYP;
  p011#rendszam VARCHAR2_11_tab_typ;
  TYPE VARCHAR2_1000_tab_typ IS TABLE OF VARCHAR2(1000) INDEX BY BINARY_INTEGER;
  p011#potd_tipus VARCHAR2_1000_tab_typ;
  p011#potd_osszeg NUMBER_12_2_tab_typ;

BEGIN
  v001.DELETE;
  p002#rendszam.DELETE;
  p002#tipus.DELETE;
  v005.DELETE;
  p006#rendszam.DELETE;
  p006#limit.DELETE;
  p006#biztossz.DELETE;
  v010.DELETE;
  p011#rendszam.DELETE;
  p011#potd_tipus.DELETE;
  p011#potd_osszeg.DELETE;

  DB_dealer.szerzodes_adatok_faf(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_jarmutip=>v001,
		p_biztossz=>v005,
		p_potd_kock=>v010);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#rendszam(i2) := v001(i1).rendszam;
    p002#tipus(i2) := v001(i1).tipus;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :5 := p002#rendszam;
  :6 := p002#tipus;
  
  i1 := v005.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p006#rendszam(i2) := v005(i1).rendszam;
    p006#limit(i2) := v005(i1).limit;
    p006#biztossz(i2) := v005(i1).biztossz;
    i1 := v005.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :7 := p006#rendszam;
  :8 := p006#limit;
  :9 := p006#biztossz;
  
  i1 := v010.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p011#rendszam(i2) := v010(i1).rendszam;
    p011#potd_tipus(i2) := v010(i1).potd_tipus;
    p011#potd_osszeg(i2) := v010(i1).potd_osszeg;
    i1 := v010.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :10 := p011#rendszam;
  :11 := p011#potd_tipus;
  :12 := p011#potd_osszeg;

END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokFaf(ctx context.Context, input *DbDealer_SzerzodesAdatokFaf_Input) (output *DbDealer_SzerzodesAdatokFaf_Output, err error) {
	params := make([]interface{}, 12)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	params[2] = output.PHibaKod  // gcs1
	params[3] = output.PHibaSzov // gcs1
	x__PJarmutip__Rendszam := make([]string, 0, 1000)
	params[4] = x__PJarmutip__Rendszam // gctr2
	x__PJarmutip__Tipus := make([]string, 0, 1000)
	params[5] = x__PJarmutip__Tipus // gctr2
	x__PBiztossz__Rendszam := make([]string, 0, 1000)
	params[6] = x__PBiztossz__Rendszam // gctr2
	x__PBiztossz__Limit := make([]float64, 0, 1000)
	params[7] = x__PBiztossz__Limit // gctr2
	x__PBiztossz__Biztossz := make([]float64, 0, 1000)
	params[8] = x__PBiztossz__Biztossz // gctr2
	x__PPotdKock__Rendszam := make([]string, 0, 1000)
	params[9] = x__PPotdKock__Rendszam // gctr2
	x__PPotdKock__PotdTipus := make([]string, 0, 1000)
	params[10] = x__PPotdKock__PotdTipus // gctr2
	x__PPotdKock__PotdOsszeg := make([]float64, 0, 1000)
	params[11] = x__PPotdKock__PotdOsszeg // gctr2

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_faf(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_jarmutip=>v001,
		p_biztossz=>v005,
		p_potd_kock=>v010)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_faf__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PJarmutip == nil { // *Db_dealer__jarmutip_rec_typ__bruno
		output.PJarmutip = make([]*DbDealer_JarmutipRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PJarmutip__Rendszam) - cap(output.PJarmutip); m > 0 {
		output.PJarmutip = append(output.PJarmutip, make([]*DbDealer_JarmutipRecTyp_Bruno, m)...)
	}
	output.PJarmutip = output.PJarmutip[:len(x__PJarmutip__Rendszam)]
	for i, v := range x__PJarmutip__Rendszam {
		if output.PJarmutip[i] != nil {
			output.PJarmutip[i].Rendszam = v
		}
	}
	if m := len(x__PJarmutip__Tipus) - cap(output.PJarmutip); m > 0 {
		output.PJarmutip = append(output.PJarmutip, make([]*DbDealer_JarmutipRecTyp_Bruno, m)...)
	}
	output.PJarmutip = output.PJarmutip[:len(x__PJarmutip__Tipus)]
	for i, v := range x__PJarmutip__Tipus {
		if output.PJarmutip[i] != nil {
			output.PJarmutip[i].Tipus = v
		}
	}

	if output.PBiztossz == nil { // *Db_dealer__faf_biztossz_rec_typ__bruno
		output.PBiztossz = make([]*DbDealer_FafBiztosszRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PBiztossz__Rendszam) - cap(output.PBiztossz); m > 0 {
		output.PBiztossz = append(output.PBiztossz, make([]*DbDealer_FafBiztosszRecTyp_Bruno, m)...)
	}
	output.PBiztossz = output.PBiztossz[:len(x__PBiztossz__Rendszam)]
	for i, v := range x__PBiztossz__Rendszam {
		if output.PBiztossz[i] != nil {
			output.PBiztossz[i].Rendszam = v
		}
	}
	if m := len(x__PBiztossz__Limit) - cap(output.PBiztossz); m > 0 {
		output.PBiztossz = append(output.PBiztossz, make([]*DbDealer_FafBiztosszRecTyp_Bruno, m)...)
	}
	output.PBiztossz = output.PBiztossz[:len(x__PBiztossz__Limit)]
	for i, v := range x__PBiztossz__Limit {
		if output.PBiztossz[i] != nil {
			output.PBiztossz[i].Limit = v
		}
	}
	if m := len(x__PBiztossz__Biztossz) - cap(output.PBiztossz); m > 0 {
		output.PBiztossz = append(output.PBiztossz, make([]*DbDealer_FafBiztosszRecTyp_Bruno, m)...)
	}
	output.PBiztossz = output.PBiztossz[:len(x__PBiztossz__Biztossz)]
	for i, v := range x__PBiztossz__Biztossz {
		if output.PBiztossz[i] != nil {
			output.PBiztossz[i].Biztossz = v
		}
	}

	if output.PPotdKock == nil { // *Db_dealer__potd_kock_rec_typ__bruno
		output.PPotdKock = make([]*DbDealer_PotdKockRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PPotdKock__Rendszam) - cap(output.PPotdKock); m > 0 {
		output.PPotdKock = append(output.PPotdKock, make([]*DbDealer_PotdKockRecTyp_Bruno, m)...)
	}
	output.PPotdKock = output.PPotdKock[:len(x__PPotdKock__Rendszam)]
	for i, v := range x__PPotdKock__Rendszam {
		if output.PPotdKock[i] != nil {
			output.PPotdKock[i].Rendszam = v
		}
	}
	if m := len(x__PPotdKock__PotdTipus) - cap(output.PPotdKock); m > 0 {
		output.PPotdKock = append(output.PPotdKock, make([]*DbDealer_PotdKockRecTyp_Bruno, m)...)
	}
	output.PPotdKock = output.PPotdKock[:len(x__PPotdKock__PotdTipus)]
	for i, v := range x__PPotdKock__PotdTipus {
		if output.PPotdKock[i] != nil {
			output.PPotdKock[i].PotdTipus = v
		}
	}
	if m := len(x__PPotdKock__PotdOsszeg) - cap(output.PPotdKock); m > 0 {
		output.PPotdKock = append(output.PPotdKock, make([]*DbDealer_PotdKockRecTyp_Bruno, m)...)
	}
	output.PPotdKock = output.PPotdKock[:len(x__PPotdKock__PotdOsszeg)]
	for i, v := range x__PPotdKock__PotdOsszeg {
		if output.PPotdKock[i] != nil {
			output.PPotdKock[i].PotdOsszeg = v
		}
	}

	return
}
const Db_dealer__szerzodes_adatok_taxi__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.szerzodes_adatok_taxi(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_rendszam=>:5,
		p_szallszem=>:6,
		p_biztossz=>:7,
		p_eng_szam=>:8);


END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokTaxi(ctx context.Context, input *DbDealer_SzerzodesAdatokTaxi_Input) (output *DbDealer_SzerzodesAdatokTaxi_Output, err error) {
	params := make([]interface{}, 8)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon      // gcs2
	params[1] = input.PSzerzAzon  // gcs2
	params[2] = output.PHibaKod   // gcs1
	params[3] = output.PHibaSzov  // gcs1
	params[4] = output.PRendszam  // gcs1
	params[5] = output.PSzallszem // gcs1
	params[6] = output.PBiztossz  // gcs1
	params[7] = output.PEngSzam   // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_taxi(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_rendszam=>:p_rendszam,
		p_szallszem=>:p_szallszem,
		p_biztossz=>:p_biztossz,
		p_eng_szam=>:p_eng_szam)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_taxi__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_adatok_bahbar__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.szerzodes_adatok_bahbar(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_biztossz_balhal=>:5,
		p_biztossz_balrokk=>:6);


END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokBahbar(ctx context.Context, input *DbDealer_SzerzodesAdatokBahbar_Input) (output *DbDealer_SzerzodesAdatokBahbar_Output, err error) {
	params := make([]interface{}, 6)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon            // gcs2
	params[1] = input.PSzerzAzon        // gcs2
	params[2] = output.PHibaKod         // gcs1
	params[3] = output.PHibaSzov        // gcs1
	params[4] = output.PBiztosszBalhal  // gcs1
	params[5] = output.PBiztosszBalrokk // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_bahbar(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_biztossz_balhal=>:p_biztossz_balhal,
		p_biztossz_balrokk=>:p_biztossz_balrokk)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_bahbar__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_adatok_260__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.szerzodes_adatok_260(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_modkod=>:5,
		p_rendszam=>:6,
		p_dijrend=>:7,
		p_kockvege=>:8,
		p_biztositasi_dijhatralek=>:9,
		p_fedezetlensegi_dijhatralek=>:10,
		p_baleseti_ado_hatralek=>:11,
		p_tagdij_hatralek=>:12,
		p_osszes_hatralek=>:13);


END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatok_260(ctx context.Context, input *DbDealer_SzerzodesAdatok_260_Input) (output *DbDealer_SzerzodesAdatok_260_Output, err error) {
	params := make([]interface{}, 13)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon                      // gcs2
	params[1] = input.PSzerzAzon                  // gcs2
	params[2] = output.PHibaKod                   // gcs1
	params[3] = output.PHibaSzov                  // gcs1
	params[4] = output.PModkod                    // gcs1
	params[5] = output.PRendszam                  // gcs1
	params[6] = output.PDijrend                   // gcs1
	params[7] = output.PKockvege                  // gcs1
	params[8] = output.PBiztositasiDijhatralek    // gcs1
	params[9] = output.PFedezetlensegiDijhatralek // gcs1
	params[10] = output.PBalesetiAdoHatralek      // gcs1
	params[11] = output.PTagdijHatralek           // gcs1
	params[12] = output.POsszesHatralek           // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_260(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_modkod=>:p_modkod,
		p_rendszam=>:p_rendszam,
		p_dijrend=>:p_dijrend,
		p_kockvege=>:p_kockvege,
		p_biztositasi_dijhatralek=>:p_biztositasi_dijhatralek,
		p_fedezetlensegi_dijhatralek=>:p_fedezetlensegi_dijhatralek,
		p_baleseti_ado_hatralek=>:p_baleseti_ado_hatralek,
		p_tagdij_hatralek=>:p_tagdij_hatralek,
		p_osszes_hatralek=>:p_osszes_hatralek)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_260__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_adatok_index__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER_KOZOS.RESZL_TAB_TYP;
  TYPE VARCHAR2_6_tab_typ IS TABLE OF VARCHAR2(6) INDEX BY BINARY_INTEGER;
  p002#modkod VARCHAR2_6_tab_typ;
  TYPE VARCHAR2_40_tab_typ IS TABLE OF VARCHAR2(40) INDEX BY BINARY_INTEGER;
  p002#modnev VARCHAR2_40_tab_typ;
  TYPE NUMBER_9_tab_typ IS TABLE OF NUMBER(9) INDEX BY BINARY_INTEGER;
  p002#evesdij NUMBER_9_tab_typ;
  TYPE NUMBER_5_2_tab_typ IS TABLE OF NUMBER(5, 2) INDEX BY BINARY_INTEGER;
  p002#szazalek NUMBER_5_2_tab_typ;

BEGIN
  v001.DELETE;
  p002#modkod.DELETE;
  p002#modnev.DELETE;
  p002#evesdij.DELETE;
  p002#szazalek.DELETE;

  DB_dealer.szerzodes_adatok_index(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_alldijsum=>:3,
		p_hataly=>:4,
		p_reszletezo=>v001,
		p_hiba_kod=>:5,
		p_hiba_szov=>:6);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#modkod(i2) := v001(i1).modkod;
    p002#modnev(i2) := v001(i1).modnev;
    p002#evesdij(i2) := v001(i1).evesdij;
    p002#szazalek(i2) := v001(i1).szazalek;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :7 := p002#evesdij;
  :8 := p002#szazalek;
  :9 := p002#modkod;
  :10 := p002#modnev;

END;
`

func (s *oracallServer) DbDealer_SzerzodesAdatokIndex(ctx context.Context, input *DbDealer_SzerzodesAdatokIndex_Input) (output *DbDealer_SzerzodesAdatokIndex_Output, err error) {
	params := make([]interface{}, 10)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon      // gcs2
	params[1] = input.PSzerzAzon  // gcs2
	params[2] = output.PAlldijsum // gcs1
	params[3] = output.PHataly    // gcs1
	x__PReszletezo__Modkod := make([]string, 0, 1000)
	params[8] = x__PReszletezo__Modkod // gctr2
	x__PReszletezo__Modnev := make([]string, 0, 1000)
	params[9] = x__PReszletezo__Modnev // gctr2
	x__PReszletezo__Evesdij := make([]float64, 0, 1000)
	params[6] = x__PReszletezo__Evesdij // gctr2
	x__PReszletezo__Szazalek := make([]float64, 0, 1000)
	params[7] = x__PReszletezo__Szazalek // gctr2
	params[4] = output.PHibaKod          // gcs1
	params[5] = output.PHibaSzov         // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_adatok_index(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_alldijsum=>:p_alldijsum,
		p_hataly=>:p_hataly,
		p_reszletezo=>v001,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_adatok_index__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PReszletezo == nil { // *Db_dealer_kozos__reszl_rec_typ__bruno
		output.PReszletezo = make([]*DbDealerKozos_ReszlRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PReszletezo__Modkod) - cap(output.PReszletezo); m > 0 {
		output.PReszletezo = append(output.PReszletezo, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PReszletezo = output.PReszletezo[:len(x__PReszletezo__Modkod)]
	for i, v := range x__PReszletezo__Modkod {
		if output.PReszletezo[i] != nil {
			output.PReszletezo[i].Modkod = v
		}
	}
	if m := len(x__PReszletezo__Modnev) - cap(output.PReszletezo); m > 0 {
		output.PReszletezo = append(output.PReszletezo, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PReszletezo = output.PReszletezo[:len(x__PReszletezo__Modnev)]
	for i, v := range x__PReszletezo__Modnev {
		if output.PReszletezo[i] != nil {
			output.PReszletezo[i].Modnev = v
		}
	}
	if m := len(x__PReszletezo__Evesdij) - cap(output.PReszletezo); m > 0 {
		output.PReszletezo = append(output.PReszletezo, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PReszletezo = output.PReszletezo[:len(x__PReszletezo__Evesdij)]
	for i, v := range x__PReszletezo__Evesdij {
		if output.PReszletezo[i] != nil {
			output.PReszletezo[i].Evesdij = v
		}
	}
	if m := len(x__PReszletezo__Szazalek) - cap(output.PReszletezo); m > 0 {
		output.PReszletezo = append(output.PReszletezo, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PReszletezo = output.PReszletezo[:len(x__PReszletezo__Szazalek)]
	for i, v := range x__PReszletezo__Szazalek {
		if output.PReszletezo[i] != nil {
			output.PReszletezo[i].Szazalek = v
		}
	}

	return
}
const Db_dealer__gepjarmu_adatok__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.gepjarmu_adatok(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		car_plate=>:5,
		car_category_letter=>:6,
		car_category=>:7,
		car_make=>:8,
		car_model=>:9,
		car_chassisnumber=>:10,
		car_make_year=>:11,
		car_traffic_date=>:12,
		car_cylinder_capacity=>:13,
		car_carrying_capacity=>:14,
		car_person_number=>:15,
		car_power_kw=>:16,
		car_door_number=>:17,
		car_chassis_type=>:18,
		car_fuel=>:19,
		car_usage=>:20,
		car_self_weight=>:21,
		car_max_weight=>:22,
		car_registration_book_id=>:23,
		car_buying_date=>:24);


END;
`

func (s *oracallServer) DbDealer_GepjarmuAdatok(ctx context.Context, input *DbDealer_GepjarmuAdatok_Input) (output *DbDealer_GepjarmuAdatok_Output, err error) {
	params := make([]interface{}, 24)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon                  // gcs2
	params[1] = input.PSzerzAzon              // gcs2
	params[2] = output.PHibaKod               // gcs1
	params[3] = output.PHibaSzov              // gcs1
	params[4] = output.CarPlate               // gcs1
	params[5] = output.CarCategoryLetter      // gcs1
	params[6] = output.CarCategory            // gcs1
	params[7] = output.CarMake                // gcs1
	params[8] = output.CarModel               // gcs1
	params[9] = output.CarChassisnumber       // gcs1
	params[10] = output.CarMakeYear           // gcs1
	params[11] = output.CarTrafficDate        // gcs1
	params[12] = output.CarCylinderCapacity   // gcs1
	params[13] = output.CarCarryingCapacity   // gcs1
	params[14] = output.CarPersonNumber       // gcs1
	params[15] = output.CarPowerKw            // gcs1
	params[16] = output.CarDoorNumber         // gcs1
	params[17] = output.CarChassisType        // gcs1
	params[18] = output.CarFuel               // gcs1
	params[19] = output.CarUsage              // gcs1
	params[20] = output.CarSelfWeight         // gcs1
	params[21] = output.CarMaxWeight          // gcs1
	params[22] = output.CarRegistrationBookId // gcs1
	params[23] = output.CarBuyingDate         // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.gepjarmu_adatok(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		car_plate=>:car_plate,
		car_category_letter=>:car_category_letter,
		car_category=>:car_category,
		car_make=>:car_make,
		car_model=>:car_model,
		car_chassisnumber=>:car_chassisnumber,
		car_make_year=>:car_make_year,
		car_traffic_date=>:car_traffic_date,
		car_cylinder_capacity=>:car_cylinder_capacity,
		car_carrying_capacity=>:car_carrying_capacity,
		car_person_number=>:car_person_number,
		car_power_kw=>:car_power_kw,
		car_door_number=>:car_door_number,
		car_chassis_type=>:car_chassis_type,
		car_fuel=>:car_fuel,
		car_usage=>:car_usage,
		car_self_weight=>:car_self_weight,
		car_max_weight=>:car_max_weight,
		car_registration_book_id=>:car_registration_book_id,
		car_buying_date=>:car_buying_date)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__gepjarmu_adatok__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__index_levelek__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.LEVEL_TAB_TYP;
  TYPE INTEGER_10_tab_typ IS TABLE OF INTEGER(10) INDEX BY BINARY_INTEGER;
  p002#sbl_azon INTEGER_10_tab_typ;
  TYPE DATE_tab_typ IS TABLE OF DATE INDEX BY BINARY_INTEGER;
  p002#datum DATE_tab_typ;
  p002#lev_azon INTEGER_10_tab_typ;
  TYPE VARCHAR2_255_tab_typ IS TABLE OF VARCHAR2(255) INDEX BY BINARY_INTEGER;
  p002#url VARCHAR2_255_tab_typ;

BEGIN
  v001.DELETE;
  p002#sbl_azon.DELETE;
  p002#datum.DELETE;
  p002#lev_azon.DELETE;
  p002#url.DELETE;

  DB_dealer.index_levelek(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_levelek=>v001,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#url(i2) := v001(i1).url;
    p002#sbl_azon(i2) := v001(i1).sbl_azon;
    p002#datum(i2) := v001(i1).datum;
    p002#lev_azon(i2) := v001(i1).lev_azon;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :5 := p002#datum;
  :6 := p002#lev_azon;
  :7 := p002#url;
  :8 := p002#sbl_azon;

END;
`

func (s *oracallServer) DbDealer_IndexLevelek(ctx context.Context, input *DbDealer_IndexLevelek_Input) (output *DbDealer_IndexLevelek_Output, err error) {
	params := make([]interface{}, 8)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	x__PLevelek__Url := make([]string, 0, 1000)
	params[6] = x__PLevelek__Url // gctr2
	x__PLevelek__SblAzon := make([]int32, 0, 1000)
	params[7] = x__PLevelek__SblAzon // gctr2
	x__PLevelek__Datum := make([]custom.Date, 0, 1000)
	params[4] = x__PLevelek__Datum // gctr2
	x__PLevelek__LevAzon := make([]int32, 0, 1000)
	params[5] = x__PLevelek__LevAzon // gctr2
	params[2] = output.PHibaKod      // gcs1
	params[3] = output.PHibaSzov     // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.index_levelek(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_levelek=>v001,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__index_levelek__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PLevelek == nil { // *Db_dealer__level_rec_typ__bruno
		output.PLevelek = make([]*DbDealer_LevelRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PLevelek__Url) - cap(output.PLevelek); m > 0 {
		output.PLevelek = append(output.PLevelek, make([]*DbDealer_LevelRecTyp_Bruno, m)...)
	}
	output.PLevelek = output.PLevelek[:len(x__PLevelek__Url)]
	for i, v := range x__PLevelek__Url {
		if output.PLevelek[i] != nil {
			output.PLevelek[i].Url = v
		}
	}
	if m := len(x__PLevelek__SblAzon) - cap(output.PLevelek); m > 0 {
		output.PLevelek = append(output.PLevelek, make([]*DbDealer_LevelRecTyp_Bruno, m)...)
	}
	output.PLevelek = output.PLevelek[:len(x__PLevelek__SblAzon)]
	for i, v := range x__PLevelek__SblAzon {
		if output.PLevelek[i] != nil {
			output.PLevelek[i].SblAzon = v
		}
	}
	if m := len(x__PLevelek__Datum) - cap(output.PLevelek); m > 0 {
		output.PLevelek = append(output.PLevelek, make([]*DbDealer_LevelRecTyp_Bruno, m)...)
	}
	output.PLevelek = output.PLevelek[:len(x__PLevelek__Datum)]
	for i, v := range x__PLevelek__Datum {
		if output.PLevelek[i] != nil {
			output.PLevelek[i].Datum = v
		}
	}
	if m := len(x__PLevelek__LevAzon) - cap(output.PLevelek); m > 0 {
		output.PLevelek = append(output.PLevelek, make([]*DbDealer_LevelRecTyp_Bruno, m)...)
	}
	output.PLevelek = output.PLevelek[:len(x__PLevelek__LevAzon)]
	for i, v := range x__PLevelek__LevAzon {
		if output.PLevelek[i] != nil {
			output.PLevelek[i].LevAzon = v
		}
	}

	return
}
const Db_dealer__ugyfel_adatok__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.ugyfel_adatok(p_bazon=>:1,
		p_ugyazon=>:2,
		p_szerz_azon=>:3,
		p_hiba_kod=>:4,
		p_hiba_szov=>:5,
		member_code=>:6,
		client_name=>:7,
		client_sex=>:8,
		client_mothersname=>:9,
		client_birthname=>:10,
		client_birthplace=>:11,
		client_birthdate=>:12,
		client_addr_pcode=>:13,
		client_addr_city=>:14,
		client_addr_street=>:15,
		client_addr_other=>:16,
		client_mail_pcode=>:17,
		client_mail_city=>:18,
		client_mail_street=>:19,
		client_mail_other=>:20,
		client_phone_home=>:21,
		client_phone_work=>:22,
		client_phone_mobile=>:23,
		client_email=>:24,
		client_taxnumber=>:25,
		client_enterpreneur=>:26,
		client_dl_date=>:27,
		client_certificate_type=>:28,
		client_certificatenumber=>:29,
		client_main_category=>:30,
		irszam=>:31,
		ktid=>:32,
		hazszam1=>:33,
		hazszam2=>:34,
		lepcsohaz=>:35,
		epulet=>:36,
		emelet=>:37,
		ajto=>:38);


END;
`

func (s *oracallServer) DbDealer_UgyfelAdatok(ctx context.Context, input *DbDealer_UgyfelAdatok_Input) (output *DbDealer_UgyfelAdatok_Output, err error) {
	params := make([]interface{}, 38)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon                    // gcs2
	params[1] = input.PUgyazon                  // gcs2
	params[2] = input.PSzerzAzon                // gcs2
	params[3] = output.PHibaKod                 // gcs1
	params[4] = output.PHibaSzov                // gcs1
	params[5] = output.MemberCode               // gcs1
	params[6] = output.ClientName               // gcs1
	params[7] = output.ClientSex                // gcs1
	params[8] = output.ClientMothersname        // gcs1
	params[9] = output.ClientBirthname          // gcs1
	params[10] = output.ClientBirthplace        // gcs1
	params[11] = output.ClientBirthdate         // gcs1
	params[12] = output.ClientAddrPcode         // gcs1
	params[13] = output.ClientAddrCity          // gcs1
	params[14] = output.ClientAddrStreet        // gcs1
	params[15] = output.ClientAddrOther         // gcs1
	params[16] = output.ClientMailPcode         // gcs1
	params[17] = output.ClientMailCity          // gcs1
	params[18] = output.ClientMailStreet        // gcs1
	params[19] = output.ClientMailOther         // gcs1
	params[20] = output.ClientPhoneHome         // gcs1
	params[21] = output.ClientPhoneWork         // gcs1
	params[22] = output.ClientPhoneMobile       // gcs1
	params[23] = output.ClientEmail             // gcs1
	params[24] = output.ClientTaxnumber         // gcs1
	params[25] = output.ClientEnterpreneur      // gcs1
	params[26] = output.ClientDlDate            // gcs1
	params[27] = output.ClientCertificateType   // gcs1
	params[28] = output.ClientCertificatenumber // gcs1
	params[29] = output.ClientMainCategory      // gcs1
	params[30] = output.Irszam                  // gcs1
	params[31] = output.Ktid                    // gcs1
	params[32] = output.Hazszam1                // gcs1
	params[33] = output.Hazszam2                // gcs1
	params[34] = output.Lepcsohaz               // gcs1
	params[35] = output.Epulet                  // gcs1
	params[36] = output.Emelet                  // gcs1
	params[37] = output.Ajto                    // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.ugyfel_adatok(p_bazon=>:p_bazon,
		p_ugyazon=>:p_ugyazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		member_code=>:member_code,
		client_name=>:client_name,
		client_sex=>:client_sex,
		client_mothersname=>:client_mothersname,
		client_birthname=>:client_birthname,
		client_birthplace=>:client_birthplace,
		client_birthdate=>:client_birthdate,
		client_addr_pcode=>:client_addr_pcode,
		client_addr_city=>:client_addr_city,
		client_addr_street=>:client_addr_street,
		client_addr_other=>:client_addr_other,
		client_mail_pcode=>:client_mail_pcode,
		client_mail_city=>:client_mail_city,
		client_mail_street=>:client_mail_street,
		client_mail_other=>:client_mail_other,
		client_phone_home=>:client_phone_home,
		client_phone_work=>:client_phone_work,
		client_phone_mobile=>:client_phone_mobile,
		client_email=>:client_email,
		client_taxnumber=>:client_taxnumber,
		client_enterpreneur=>:client_enterpreneur,
		client_dl_date=>:client_dl_date,
		client_certificate_type=>:client_certificate_type,
		client_certificatenumber=>:client_certificatenumber,
		client_main_category=>:client_main_category,
		irszam=>:irszam,
		ktid=>:ktid,
		hazszam1=>:hazszam1,
		hazszam2=>:hazszam2,
		lepcsohaz=>:lepcsohaz,
		epulet=>:epulet,
		emelet=>:emelet,
		ajto=>:ajto)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__ugyfel_adatok__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__ugynok_adatok__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.ugynok_adatok(p_bazon=>:1,
		p_torzsszam=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		dealer_name=>:5,
		dealer_sex=>:6,
		dealer_mothersname=>:7,
		dealer_birthname=>:8,
		dealer_birthplace=>:9,
		dealer_birthdate=>:10,
		dealer_addr_pcode=>:11,
		dealer_addr_city=>:12,
		dealer_addr_street=>:13,
		dealer_addr_other=>:14,
		dealer_mail_pcode=>:15,
		dealer_mail_city=>:16,
		dealer_mail_street=>:17,
		dealer_mail_other=>:18,
		dealer_phone_home=>:19,
		dealer_phone_work=>:20,
		dealer_phone_mobile=>:21,
		dealer_email=>:22,
		dealer_taxnumber=>:23,
		dealer_enterpreneur=>:24,
		dealer_dl_date=>:25,
		dealer_certificate_type=>:26,
		dealer_certificatenumber=>:27,
		dealer_main_category=>:28,
		dealer_begin=>:29,
		dealer_quit=>:30,
		dealer_exams=>:31,
		dealer_reg_code=>:32,
		dealer_bank_account=>:33);


END;
`

func (s *oracallServer) DbDealer_UgynokAdatok(ctx context.Context, input *DbDealer_UgynokAdatok_Input) (output *DbDealer_UgynokAdatok_Output, err error) {
	params := make([]interface{}, 33)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon                    // gcs2
	params[1] = input.PTorzsszam                // gcs2
	params[2] = output.PHibaKod                 // gcs1
	params[3] = output.PHibaSzov                // gcs1
	params[4] = output.DealerName               // gcs1
	params[5] = output.DealerSex                // gcs1
	params[6] = output.DealerMothersname        // gcs1
	params[7] = output.DealerBirthname          // gcs1
	params[8] = output.DealerBirthplace         // gcs1
	params[9] = output.DealerBirthdate          // gcs1
	params[10] = output.DealerAddrPcode         // gcs1
	params[11] = output.DealerAddrCity          // gcs1
	params[12] = output.DealerAddrStreet        // gcs1
	params[13] = output.DealerAddrOther         // gcs1
	params[14] = output.DealerMailPcode         // gcs1
	params[15] = output.DealerMailCity          // gcs1
	params[16] = output.DealerMailStreet        // gcs1
	params[17] = output.DealerMailOther         // gcs1
	params[18] = output.DealerPhoneHome         // gcs1
	params[19] = output.DealerPhoneWork         // gcs1
	params[20] = output.DealerPhoneMobile       // gcs1
	params[21] = output.DealerEmail             // gcs1
	params[22] = output.DealerTaxnumber         // gcs1
	params[23] = output.DealerEnterpreneur      // gcs1
	params[24] = output.DealerDlDate            // gcs1
	params[25] = output.DealerCertificateType   // gcs1
	params[26] = output.DealerCertificatenumber // gcs1
	params[27] = output.DealerMainCategory      // gcs1
	params[28] = output.DealerBegin             // gcs1
	params[29] = output.DealerQuit              // gcs1
	params[30] = output.DealerExams             // gcs1
	params[31] = output.DealerRegCode           // gcs1
	params[32] = output.DealerBankAccount       // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.ugynok_adatok(p_bazon=>:p_bazon,
		p_torzsszam=>:p_torzsszam,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		dealer_name=>:dealer_name,
		dealer_sex=>:dealer_sex,
		dealer_mothersname=>:dealer_mothersname,
		dealer_birthname=>:dealer_birthname,
		dealer_birthplace=>:dealer_birthplace,
		dealer_birthdate=>:dealer_birthdate,
		dealer_addr_pcode=>:dealer_addr_pcode,
		dealer_addr_city=>:dealer_addr_city,
		dealer_addr_street=>:dealer_addr_street,
		dealer_addr_other=>:dealer_addr_other,
		dealer_mail_pcode=>:dealer_mail_pcode,
		dealer_mail_city=>:dealer_mail_city,
		dealer_mail_street=>:dealer_mail_street,
		dealer_mail_other=>:dealer_mail_other,
		dealer_phone_home=>:dealer_phone_home,
		dealer_phone_work=>:dealer_phone_work,
		dealer_phone_mobile=>:dealer_phone_mobile,
		dealer_email=>:dealer_email,
		dealer_taxnumber=>:dealer_taxnumber,
		dealer_enterpreneur=>:dealer_enterpreneur,
		dealer_dl_date=>:dealer_dl_date,
		dealer_certificate_type=>:dealer_certificate_type,
		dealer_certificatenumber=>:dealer_certificatenumber,
		dealer_main_category=>:dealer_main_category,
		dealer_begin=>:dealer_begin,
		dealer_quit=>:dealer_quit,
		dealer_exams=>:dealer_exams,
		dealer_reg_code=>:dealer_reg_code,
		dealer_bank_account=>:dealer_bank_account)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__ugynok_adatok__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__ugynok_adatok_torzsszam__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.ugynok_adatok_torzsszam(p_torzsszam=>:1,
		p_hiba_kod=>:2,
		p_hiba_szov=>:3,
		dealer_name=>:4,
		dealer_sex=>:5,
		dealer_mothersname=>:6,
		dealer_birthname=>:7,
		dealer_birthplace=>:8,
		dealer_birthdate=>:9,
		dealer_addr_pcode=>:10,
		dealer_addr_city=>:11,
		dealer_addr_street=>:12,
		dealer_addr_other=>:13,
		dealer_mail_pcode=>:14,
		dealer_mail_city=>:15,
		dealer_mail_street=>:16,
		dealer_mail_other=>:17,
		dealer_phone_home=>:18,
		dealer_phone_work=>:19,
		dealer_phone_mobile=>:20,
		dealer_email=>:21,
		dealer_taxnumber=>:22,
		dealer_enterpreneur=>:23,
		dealer_dl_date=>:24,
		dealer_certificate_type=>:25,
		dealer_certificatenumber=>:26,
		dealer_main_category=>:27,
		dealer_begin=>:28,
		dealer_quit=>:29,
		dealer_exams=>:30,
		dealer_reg_code=>:31,
		dealer_bank_account=>:32);


END;
`

func (s *oracallServer) DbDealer_UgynokAdatokTorzsszam(ctx context.Context, input *DbDealer_UgynokAdatokTorzsszam_Input) (output *DbDealer_UgynokAdatokTorzsszam_Output, err error) {
	params := make([]interface{}, 32)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PTorzsszam                // gcs2
	params[1] = output.PHibaKod                 // gcs1
	params[2] = output.PHibaSzov                // gcs1
	params[3] = output.DealerName               // gcs1
	params[4] = output.DealerSex                // gcs1
	params[5] = output.DealerMothersname        // gcs1
	params[6] = output.DealerBirthname          // gcs1
	params[7] = output.DealerBirthplace         // gcs1
	params[8] = output.DealerBirthdate          // gcs1
	params[9] = output.DealerAddrPcode          // gcs1
	params[10] = output.DealerAddrCity          // gcs1
	params[11] = output.DealerAddrStreet        // gcs1
	params[12] = output.DealerAddrOther         // gcs1
	params[13] = output.DealerMailPcode         // gcs1
	params[14] = output.DealerMailCity          // gcs1
	params[15] = output.DealerMailStreet        // gcs1
	params[16] = output.DealerMailOther         // gcs1
	params[17] = output.DealerPhoneHome         // gcs1
	params[18] = output.DealerPhoneWork         // gcs1
	params[19] = output.DealerPhoneMobile       // gcs1
	params[20] = output.DealerEmail             // gcs1
	params[21] = output.DealerTaxnumber         // gcs1
	params[22] = output.DealerEnterpreneur      // gcs1
	params[23] = output.DealerDlDate            // gcs1
	params[24] = output.DealerCertificateType   // gcs1
	params[25] = output.DealerCertificatenumber // gcs1
	params[26] = output.DealerMainCategory      // gcs1
	params[27] = output.DealerBegin             // gcs1
	params[28] = output.DealerQuit              // gcs1
	params[29] = output.DealerExams             // gcs1
	params[30] = output.DealerRegCode           // gcs1
	params[31] = output.DealerBankAccount       // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.ugynok_adatok_torzsszam(p_torzsszam=>:p_torzsszam,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		dealer_name=>:dealer_name,
		dealer_sex=>:dealer_sex,
		dealer_mothersname=>:dealer_mothersname,
		dealer_birthname=>:dealer_birthname,
		dealer_birthplace=>:dealer_birthplace,
		dealer_birthdate=>:dealer_birthdate,
		dealer_addr_pcode=>:dealer_addr_pcode,
		dealer_addr_city=>:dealer_addr_city,
		dealer_addr_street=>:dealer_addr_street,
		dealer_addr_other=>:dealer_addr_other,
		dealer_mail_pcode=>:dealer_mail_pcode,
		dealer_mail_city=>:dealer_mail_city,
		dealer_mail_street=>:dealer_mail_street,
		dealer_mail_other=>:dealer_mail_other,
		dealer_phone_home=>:dealer_phone_home,
		dealer_phone_work=>:dealer_phone_work,
		dealer_phone_mobile=>:dealer_phone_mobile,
		dealer_email=>:dealer_email,
		dealer_taxnumber=>:dealer_taxnumber,
		dealer_enterpreneur=>:dealer_enterpreneur,
		dealer_dl_date=>:dealer_dl_date,
		dealer_certificate_type=>:dealer_certificate_type,
		dealer_certificatenumber=>:dealer_certificatenumber,
		dealer_main_category=>:dealer_main_category,
		dealer_begin=>:dealer_begin,
		dealer_quit=>:dealer_quit,
		dealer_exams=>:dealer_exams,
		dealer_reg_code=>:dealer_reg_code,
		dealer_bank_account=>:dealer_bank_account)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__ugynok_adatok_torzsszam__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_bef_mabisz__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.szerzodes_bef_mabisz(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hatalytol=>:3,
		p_hatalyig=>:4,
		p_elvaras=>:5,
		p_teljesites=>:6,
		p_teljesites_dat=>:7,
		p_hiba_kod=>:8,
		p_hiba_szov=>:9);


END;
`

func (s *oracallServer) DbDealer_SzerzodesBefMabisz(ctx context.Context, input *DbDealer_SzerzodesBefMabisz_Input) (output *DbDealer_SzerzodesBefMabisz_Output, err error) {
	params := make([]interface{}, 9)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon          // gcs2
	params[1] = input.PSzerzAzon      // gcs2
	params[2] = output.PHatalytol     // gcs1
	params[3] = output.PHatalyig      // gcs1
	params[4] = output.PElvaras       // gcs1
	params[5] = output.PTeljesites    // gcs1
	params[6] = output.PTeljesitesDat // gcs1
	params[7] = output.PHibaKod       // gcs1
	params[8] = output.PHibaSzov      // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_bef_mabisz(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hatalytol=>:p_hatalytol,
		p_hatalyig=>:p_hatalyig,
		p_elvaras=>:p_elvaras,
		p_teljesites=>:p_teljesites,
		p_teljesites_dat=>:p_teljesites_dat,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_bef_mabisz__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_befizetesek__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.BEFIZETES_TAB_TYP;
  TYPE NUMBER_12_2_tab_typ IS TABLE OF NUMBER(12, 2) INDEX BY BINARY_INTEGER;
  p002#paying_amount NUMBER_12_2_tab_typ;
  TYPE VARCHAR2_80_tab_typ IS TABLE OF VARCHAR2(80) INDEX BY BINARY_INTEGER;
  p002#paying_reason VARCHAR2_80_tab_typ;
  TYPE NUMBER_12_tab_typ IS TABLE OF NUMBER(12) INDEX BY BINARY_INTEGER;
  p002#paying_id NUMBER_12_tab_typ;
  TYPE NUMBER_4_tab_typ IS TABLE OF NUMBER(4) INDEX BY BINARY_INTEGER;
  p002#actyear NUMBER_4_tab_typ;
  TYPE DATE_tab_typ IS TABLE OF DATE INDEX BY BINARY_INTEGER;
  p002#paying_date DATE_tab_typ;
  p002#paying_credit_date DATE_tab_typ;
  v009 BRUNO.DB_DEALER.BEFIZETES_TAB_TYP;
  p010#paying_date DATE_tab_typ;
  p010#paying_credit_date DATE_tab_typ;
  p010#paying_amount NUMBER_12_2_tab_typ;
  p010#paying_reason VARCHAR2_80_tab_typ;
  p010#paying_id NUMBER_12_tab_typ;
  p010#actyear NUMBER_4_tab_typ;

BEGIN
  v001.DELETE;
  p002#paying_amount.DELETE;
  p002#paying_reason.DELETE;
  p002#paying_id.DELETE;
  p002#actyear.DELETE;
  p002#paying_date.DELETE;
  p002#paying_credit_date.DELETE;
  v009.DELETE;
  p010#paying_date.DELETE;
  p010#paying_credit_date.DELETE;
  p010#paying_amount.DELETE;
  p010#paying_reason.DELETE;
  p010#paying_id.DELETE;
  p010#actyear.DELETE;

  DB_dealer.szerzodes_befizetesek(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_novekedes=>v001,
		p_csokkenes=>v009,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#paying_id(i2) := v001(i1).paying_id;
    p002#actyear(i2) := v001(i1).actyear;
    p002#paying_date(i2) := v001(i1).paying_date;
    p002#paying_credit_date(i2) := v001(i1).paying_credit_date;
    p002#paying_amount(i2) := v001(i1).paying_amount;
    p002#paying_reason(i2) := v001(i1).paying_reason;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :5 := p002#paying_date;
  :6 := p002#paying_credit_date;
  :7 := p002#paying_amount;
  :8 := p002#paying_reason;
  :9 := p002#paying_id;
  :10 := p002#actyear;
  
  i1 := v009.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p010#paying_reason(i2) := v009(i1).paying_reason;
    p010#paying_id(i2) := v009(i1).paying_id;
    p010#actyear(i2) := v009(i1).actyear;
    p010#paying_date(i2) := v009(i1).paying_date;
    p010#paying_credit_date(i2) := v009(i1).paying_credit_date;
    p010#paying_amount(i2) := v009(i1).paying_amount;
    i1 := v009.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :11 := p010#paying_credit_date;
  :12 := p010#paying_amount;
  :13 := p010#paying_reason;
  :14 := p010#paying_id;
  :15 := p010#actyear;
  :16 := p010#paying_date;

END;
`

func (s *oracallServer) DbDealer_SzerzodesBefizetesek(ctx context.Context, input *DbDealer_SzerzodesBefizetesek_Input) (output *DbDealer_SzerzodesBefizetesek_Output, err error) {
	params := make([]interface{}, 16)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	x__PNovekedes__PayingId := make([]float64, 0, 1000)
	params[8] = x__PNovekedes__PayingId // gctr2
	x__PNovekedes__Actyear := make([]float64, 0, 1000)
	params[9] = x__PNovekedes__Actyear // gctr2
	x__PNovekedes__PayingDate := make([]custom.Date, 0, 1000)
	params[4] = x__PNovekedes__PayingDate // gctr2
	x__PNovekedes__PayingCreditDate := make([]custom.Date, 0, 1000)
	params[5] = x__PNovekedes__PayingCreditDate // gctr2
	x__PNovekedes__PayingAmount := make([]float64, 0, 1000)
	params[6] = x__PNovekedes__PayingAmount // gctr2
	x__PNovekedes__PayingReason := make([]string, 0, 1000)
	params[7] = x__PNovekedes__PayingReason // gctr2
	x__PCsokkenes__PayingReason := make([]string, 0, 1000)
	params[12] = x__PCsokkenes__PayingReason // gctr2
	x__PCsokkenes__PayingId := make([]float64, 0, 1000)
	params[13] = x__PCsokkenes__PayingId // gctr2
	x__PCsokkenes__Actyear := make([]float64, 0, 1000)
	params[14] = x__PCsokkenes__Actyear // gctr2
	x__PCsokkenes__PayingDate := make([]custom.Date, 0, 1000)
	params[15] = x__PCsokkenes__PayingDate // gctr2
	x__PCsokkenes__PayingCreditDate := make([]custom.Date, 0, 1000)
	params[10] = x__PCsokkenes__PayingCreditDate // gctr2
	x__PCsokkenes__PayingAmount := make([]float64, 0, 1000)
	params[11] = x__PCsokkenes__PayingAmount // gctr2
	params[2] = output.PHibaKod              // gcs1
	params[3] = output.PHibaSzov             // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_befizetesek(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_novekedes=>v001,
		p_csokkenes=>v009,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_befizetesek__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PNovekedes == nil { // *Db_dealer__befizetes_rec_typ__bruno
		output.PNovekedes = make([]*DbDealer_BefizetesRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PNovekedes__PayingId) - cap(output.PNovekedes); m > 0 {
		output.PNovekedes = append(output.PNovekedes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PNovekedes = output.PNovekedes[:len(x__PNovekedes__PayingId)]
	for i, v := range x__PNovekedes__PayingId {
		if output.PNovekedes[i] != nil {
			output.PNovekedes[i].PayingId = v
		}
	}
	if m := len(x__PNovekedes__Actyear) - cap(output.PNovekedes); m > 0 {
		output.PNovekedes = append(output.PNovekedes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PNovekedes = output.PNovekedes[:len(x__PNovekedes__Actyear)]
	for i, v := range x__PNovekedes__Actyear {
		if output.PNovekedes[i] != nil {
			output.PNovekedes[i].Actyear = v
		}
	}
	if m := len(x__PNovekedes__PayingDate) - cap(output.PNovekedes); m > 0 {
		output.PNovekedes = append(output.PNovekedes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PNovekedes = output.PNovekedes[:len(x__PNovekedes__PayingDate)]
	for i, v := range x__PNovekedes__PayingDate {
		if output.PNovekedes[i] != nil {
			output.PNovekedes[i].PayingDate = v
		}
	}
	if m := len(x__PNovekedes__PayingCreditDate) - cap(output.PNovekedes); m > 0 {
		output.PNovekedes = append(output.PNovekedes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PNovekedes = output.PNovekedes[:len(x__PNovekedes__PayingCreditDate)]
	for i, v := range x__PNovekedes__PayingCreditDate {
		if output.PNovekedes[i] != nil {
			output.PNovekedes[i].PayingCreditDate = v
		}
	}
	if m := len(x__PNovekedes__PayingAmount) - cap(output.PNovekedes); m > 0 {
		output.PNovekedes = append(output.PNovekedes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PNovekedes = output.PNovekedes[:len(x__PNovekedes__PayingAmount)]
	for i, v := range x__PNovekedes__PayingAmount {
		if output.PNovekedes[i] != nil {
			output.PNovekedes[i].PayingAmount = v
		}
	}
	if m := len(x__PNovekedes__PayingReason) - cap(output.PNovekedes); m > 0 {
		output.PNovekedes = append(output.PNovekedes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PNovekedes = output.PNovekedes[:len(x__PNovekedes__PayingReason)]
	for i, v := range x__PNovekedes__PayingReason {
		if output.PNovekedes[i] != nil {
			output.PNovekedes[i].PayingReason = v
		}
	}

	if output.PCsokkenes == nil { // *Db_dealer__befizetes_rec_typ__bruno
		output.PCsokkenes = make([]*DbDealer_BefizetesRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PCsokkenes__PayingReason) - cap(output.PCsokkenes); m > 0 {
		output.PCsokkenes = append(output.PCsokkenes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PCsokkenes = output.PCsokkenes[:len(x__PCsokkenes__PayingReason)]
	for i, v := range x__PCsokkenes__PayingReason {
		if output.PCsokkenes[i] != nil {
			output.PCsokkenes[i].PayingReason = v
		}
	}
	if m := len(x__PCsokkenes__PayingId) - cap(output.PCsokkenes); m > 0 {
		output.PCsokkenes = append(output.PCsokkenes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PCsokkenes = output.PCsokkenes[:len(x__PCsokkenes__PayingId)]
	for i, v := range x__PCsokkenes__PayingId {
		if output.PCsokkenes[i] != nil {
			output.PCsokkenes[i].PayingId = v
		}
	}
	if m := len(x__PCsokkenes__Actyear) - cap(output.PCsokkenes); m > 0 {
		output.PCsokkenes = append(output.PCsokkenes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PCsokkenes = output.PCsokkenes[:len(x__PCsokkenes__Actyear)]
	for i, v := range x__PCsokkenes__Actyear {
		if output.PCsokkenes[i] != nil {
			output.PCsokkenes[i].Actyear = v
		}
	}
	if m := len(x__PCsokkenes__PayingDate) - cap(output.PCsokkenes); m > 0 {
		output.PCsokkenes = append(output.PCsokkenes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PCsokkenes = output.PCsokkenes[:len(x__PCsokkenes__PayingDate)]
	for i, v := range x__PCsokkenes__PayingDate {
		if output.PCsokkenes[i] != nil {
			output.PCsokkenes[i].PayingDate = v
		}
	}
	if m := len(x__PCsokkenes__PayingCreditDate) - cap(output.PCsokkenes); m > 0 {
		output.PCsokkenes = append(output.PCsokkenes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PCsokkenes = output.PCsokkenes[:len(x__PCsokkenes__PayingCreditDate)]
	for i, v := range x__PCsokkenes__PayingCreditDate {
		if output.PCsokkenes[i] != nil {
			output.PCsokkenes[i].PayingCreditDate = v
		}
	}
	if m := len(x__PCsokkenes__PayingAmount) - cap(output.PCsokkenes); m > 0 {
		output.PCsokkenes = append(output.PCsokkenes, make([]*DbDealer_BefizetesRecTyp_Bruno, m)...)
	}
	output.PCsokkenes = output.PCsokkenes[:len(x__PCsokkenes__PayingAmount)]
	for i, v := range x__PCsokkenes__PayingAmount {
		if output.PCsokkenes[i] != nil {
			output.PCsokkenes[i].PayingAmount = v
		}
	}

	return
}
const Db_dealer__szerzodes_dijeloirasok2__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.DIJELOIRAS_TAB_TYP;
  TYPE DATE_tab_typ IS TABLE OF DATE INDEX BY BINARY_INTEGER;
  p002#tol DATE_tab_typ;
  p002#ig DATE_tab_typ;
  TYPE NUMBER_12_2_tab_typ IS TABLE OF NUMBER(12, 2) INDEX BY BINARY_INTEGER;
  p002#osszeg NUMBER_12_2_tab_typ;

BEGIN
  v001.DELETE;
  p002#tol.DELETE;
  p002#ig.DELETE;
  p002#osszeg.DELETE;

  DB_dealer.szerzodes_dijeloirasok2(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_rendszam=>:3,
		p_dijeloirasok=>v001,
		p_hiba_kod=>:4,
		p_hiba_szov=>:5);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#ig(i2) := v001(i1).ig;
    p002#osszeg(i2) := v001(i1).osszeg;
    p002#tol(i2) := v001(i1).tol;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :6 := p002#tol;
  :7 := p002#ig;
  :8 := p002#osszeg;

END;
`

func (s *oracallServer) DbDealer_SzerzodesDijeloirasok2(ctx context.Context, input *DbDealer_SzerzodesDijeloirasok2_Input) (output *DbDealer_SzerzodesDijeloirasok2_Output, err error) {
	params := make([]interface{}, 8)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	params[2] = input.PRendszam  // gcs2
	x__PDijeloirasok__Ig := make([]custom.Date, 0, 1000)
	params[6] = x__PDijeloirasok__Ig // gctr2
	x__PDijeloirasok__Osszeg := make([]float64, 0, 1000)
	params[7] = x__PDijeloirasok__Osszeg // gctr2
	x__PDijeloirasok__Tol := make([]custom.Date, 0, 1000)
	params[5] = x__PDijeloirasok__Tol // gctr2
	params[3] = output.PHibaKod       // gcs1
	params[4] = output.PHibaSzov      // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_dijeloirasok2(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_rendszam=>:p_rendszam,
		p_dijeloirasok=>v001,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_dijeloirasok2__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PDijeloirasok == nil { // *Db_dealer__dijeloiras_rec_typ__bruno
		output.PDijeloirasok = make([]*DbDealer_DijeloirasRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PDijeloirasok__Ig) - cap(output.PDijeloirasok); m > 0 {
		output.PDijeloirasok = append(output.PDijeloirasok, make([]*DbDealer_DijeloirasRecTyp_Bruno, m)...)
	}
	output.PDijeloirasok = output.PDijeloirasok[:len(x__PDijeloirasok__Ig)]
	for i, v := range x__PDijeloirasok__Ig {
		if output.PDijeloirasok[i] != nil {
			output.PDijeloirasok[i].Ig = v
		}
	}
	if m := len(x__PDijeloirasok__Osszeg) - cap(output.PDijeloirasok); m > 0 {
		output.PDijeloirasok = append(output.PDijeloirasok, make([]*DbDealer_DijeloirasRecTyp_Bruno, m)...)
	}
	output.PDijeloirasok = output.PDijeloirasok[:len(x__PDijeloirasok__Osszeg)]
	for i, v := range x__PDijeloirasok__Osszeg {
		if output.PDijeloirasok[i] != nil {
			output.PDijeloirasok[i].Osszeg = v
		}
	}
	if m := len(x__PDijeloirasok__Tol) - cap(output.PDijeloirasok); m > 0 {
		output.PDijeloirasok = append(output.PDijeloirasok, make([]*DbDealer_DijeloirasRecTyp_Bruno, m)...)
	}
	output.PDijeloirasok = output.PDijeloirasok[:len(x__PDijeloirasok__Tol)]
	for i, v := range x__PDijeloirasok__Tol {
		if output.PDijeloirasok[i] != nil {
			output.PDijeloirasok[i].Tol = v
		}
	}

	return
}
const Db_dealer__szerzodes_ba_reszletek__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.BA_RESZLET_TAB_TYP;
  TYPE DATE_tab_typ IS TABLE OF DATE INDEX BY BINARY_INTEGER;
  p002#ig DATE_tab_typ;
  TYPE NUMBER_tab_typ IS TABLE OF NUMBER INDEX BY BINARY_INTEGER;
  p002#elvaras NUMBER_tab_typ;
  p002#befizetes NUMBER_tab_typ;
  p002#evfordulo DATE_tab_typ;
  p002#tol DATE_tab_typ;

BEGIN
  v001.DELETE;
  p002#ig.DELETE;
  p002#elvaras.DELETE;
  p002#befizetes.DELETE;
  p002#evfordulo.DELETE;
  p002#tol.DELETE;

  DB_dealer.szerzodes_ba_reszletek(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_rendszam=>:3,
		p_ado_egyenleg=>:4,
		p_adorend=>:5,
		p_ba_reszletek=>v001,
		p_hiba_kod=>:6,
		p_hiba_szov=>:7);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#tol(i2) := v001(i1).tol;
    p002#ig(i2) := v001(i1).ig;
    p002#elvaras(i2) := v001(i1).elvaras;
    p002#befizetes(i2) := v001(i1).befizetes;
    p002#evfordulo(i2) := v001(i1).evfordulo;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :8 := p002#elvaras;
  :9 := p002#befizetes;
  :10 := p002#evfordulo;
  :11 := p002#tol;
  :12 := p002#ig;

END;
`

func (s *oracallServer) DbDealer_SzerzodesBaReszletek(ctx context.Context, input *DbDealer_SzerzodesBaReszletek_Input) (output *DbDealer_SzerzodesBaReszletek_Output, err error) {
	params := make([]interface{}, 12)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon        // gcs2
	params[1] = input.PSzerzAzon    // gcs2
	params[2] = input.PRendszam     // gcs2
	params[3] = output.PAdoEgyenleg // gcs1
	params[4] = output.PAdorend     // gcs1
	x__PBaReszletek__Tol := make([]custom.Date, 0, 1000)
	params[10] = x__PBaReszletek__Tol // gctr2
	x__PBaReszletek__Ig := make([]custom.Date, 0, 1000)
	params[11] = x__PBaReszletek__Ig // gctr2
	x__PBaReszletek__Elvaras := make([]float64, 0, 1000)
	params[7] = x__PBaReszletek__Elvaras // gctr2
	x__PBaReszletek__Befizetes := make([]float64, 0, 1000)
	params[8] = x__PBaReszletek__Befizetes // gctr2
	x__PBaReszletek__Evfordulo := make([]custom.Date, 0, 1000)
	params[9] = x__PBaReszletek__Evfordulo // gctr2
	params[5] = output.PHibaKod            // gcs1
	params[6] = output.PHibaSzov           // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_ba_reszletek(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_rendszam=>:p_rendszam,
		p_ado_egyenleg=>:p_ado_egyenleg,
		p_adorend=>:p_adorend,
		p_ba_reszletek=>v001,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_ba_reszletek__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PBaReszletek == nil { // *Db_dealer__ba_reszlet_rec_typ__bruno
		output.PBaReszletek = make([]*DbDealer_BaReszletRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PBaReszletek__Tol) - cap(output.PBaReszletek); m > 0 {
		output.PBaReszletek = append(output.PBaReszletek, make([]*DbDealer_BaReszletRecTyp_Bruno, m)...)
	}
	output.PBaReszletek = output.PBaReszletek[:len(x__PBaReszletek__Tol)]
	for i, v := range x__PBaReszletek__Tol {
		if output.PBaReszletek[i] != nil {
			output.PBaReszletek[i].Tol = v
		}
	}
	if m := len(x__PBaReszletek__Ig) - cap(output.PBaReszletek); m > 0 {
		output.PBaReszletek = append(output.PBaReszletek, make([]*DbDealer_BaReszletRecTyp_Bruno, m)...)
	}
	output.PBaReszletek = output.PBaReszletek[:len(x__PBaReszletek__Ig)]
	for i, v := range x__PBaReszletek__Ig {
		if output.PBaReszletek[i] != nil {
			output.PBaReszletek[i].Ig = v
		}
	}
	if m := len(x__PBaReszletek__Elvaras) - cap(output.PBaReszletek); m > 0 {
		output.PBaReszletek = append(output.PBaReszletek, make([]*DbDealer_BaReszletRecTyp_Bruno, m)...)
	}
	output.PBaReszletek = output.PBaReszletek[:len(x__PBaReszletek__Elvaras)]
	for i, v := range x__PBaReszletek__Elvaras {
		if output.PBaReszletek[i] != nil {
			output.PBaReszletek[i].Elvaras = v
		}
	}
	if m := len(x__PBaReszletek__Befizetes) - cap(output.PBaReszletek); m > 0 {
		output.PBaReszletek = append(output.PBaReszletek, make([]*DbDealer_BaReszletRecTyp_Bruno, m)...)
	}
	output.PBaReszletek = output.PBaReszletek[:len(x__PBaReszletek__Befizetes)]
	for i, v := range x__PBaReszletek__Befizetes {
		if output.PBaReszletek[i] != nil {
			output.PBaReszletek[i].Befizetes = v
		}
	}
	if m := len(x__PBaReszletek__Evfordulo) - cap(output.PBaReszletek); m > 0 {
		output.PBaReszletek = append(output.PBaReszletek, make([]*DbDealer_BaReszletRecTyp_Bruno, m)...)
	}
	output.PBaReszletek = output.PBaReszletek[:len(x__PBaReszletek__Evfordulo)]
	for i, v := range x__PBaReszletek__Evfordulo {
		if output.PBaReszletek[i] != nil {
			output.PBaReszletek[i].Evfordulo = v
		}
	}

	return
}
const Db_dealer__szerzodes_egyeb_dijak__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.DIJTABLA_TAB_TYP;
  TYPE INTEGER_10_tab_typ IS TABLE OF INTEGER(10) INDEX BY BINARY_INTEGER;
  p002#szerz_azon INTEGER_10_tab_typ;
  TYPE NUMBER_12_2_tab_typ IS TABLE OF NUMBER(12, 2) INDEX BY BINARY_INTEGER;
  p002#osszeg NUMBER_12_2_tab_typ;
  TYPE DATE_tab_typ IS TABLE OF DATE INDEX BY BINARY_INTEGER;
  p002#dijbeido DATE_tab_typ;
  TYPE VARCHAR2_40_tab_typ IS TABLE OF VARCHAR2(40) INDEX BY BINARY_INTEGER;
  p002#bizaz VARCHAR2_40_tab_typ;
  v007 BRUNO.DB_DEALER.DIJTABLA_TAB_TYP;
  p008#szerz_azon INTEGER_10_tab_typ;
  p008#osszeg NUMBER_12_2_tab_typ;
  p008#dijbeido DATE_tab_typ;
  p008#bizaz VARCHAR2_40_tab_typ;

BEGIN
  v001.DELETE;
  p002#szerz_azon.DELETE;
  p002#osszeg.DELETE;
  p002#dijbeido.DELETE;
  p002#bizaz.DELETE;
  v007.DELETE;
  p008#szerz_azon.DELETE;
  p008#osszeg.DELETE;
  p008#dijbeido.DELETE;
  p008#bizaz.DELETE;

  DB_dealer.szerzodes_egyeb_dijak(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_rendszam=>:3,
		p_elvi_dijhatralek=>:4,
		p_elmaradt_dij_befiz=>v001,
		p_mabisz_hatalytol=>:5,
		p_mabisz_hatalyig=>:6,
		p_mabisz_elvaras=>:7,
		p_mabisz_befiz=>v007,
		p_balado_adoelvar=>:8,
		p_balado_adobefiz=>:9,
		p_balado_fin_adotartoz=>:10,
		p_hiba_kod=>:11,
		p_hiba_szov=>:12);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#szerz_azon(i2) := v001(i1).szerz_azon;
    p002#osszeg(i2) := v001(i1).osszeg;
    p002#dijbeido(i2) := v001(i1).dijbeido;
    p002#bizaz(i2) := v001(i1).bizaz;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :13 := p002#szerz_azon;
  :14 := p002#osszeg;
  :15 := p002#dijbeido;
  :16 := p002#bizaz;
  
  i1 := v007.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p008#osszeg(i2) := v007(i1).osszeg;
    p008#dijbeido(i2) := v007(i1).dijbeido;
    p008#bizaz(i2) := v007(i1).bizaz;
    p008#szerz_azon(i2) := v007(i1).szerz_azon;
    i1 := v007.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :17 := p008#szerz_azon;
  :18 := p008#osszeg;
  :19 := p008#dijbeido;
  :20 := p008#bizaz;

END;
`

func (s *oracallServer) DbDealer_SzerzodesEgyebDijak(ctx context.Context, input *DbDealer_SzerzodesEgyebDijak_Input) (output *DbDealer_SzerzodesEgyebDijak_Output, err error) {
	params := make([]interface{}, 20)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon            // gcs2
	params[1] = input.PSzerzAzon        // gcs2
	params[2] = input.PRendszam         // gcs2
	params[3] = output.PElviDijhatralek // gcs1
	x__PElmaradtDijBefiz__SzerzAzon := make([]int32, 0, 1000)
	params[12] = x__PElmaradtDijBefiz__SzerzAzon // gctr2
	x__PElmaradtDijBefiz__Osszeg := make([]float64, 0, 1000)
	params[13] = x__PElmaradtDijBefiz__Osszeg // gctr2
	x__PElmaradtDijBefiz__Dijbeido := make([]custom.Date, 0, 1000)
	params[14] = x__PElmaradtDijBefiz__Dijbeido // gctr2
	x__PElmaradtDijBefiz__Bizaz := make([]string, 0, 1000)
	params[15] = x__PElmaradtDijBefiz__Bizaz // gctr2
	params[4] = output.PMabiszHatalytol      // gcs1
	params[5] = output.PMabiszHatalyig       // gcs1
	params[6] = output.PMabiszElvaras        // gcs1
	x__PMabiszBefiz__Osszeg := make([]float64, 0, 1000)
	params[17] = x__PMabiszBefiz__Osszeg // gctr2
	x__PMabiszBefiz__Dijbeido := make([]custom.Date, 0, 1000)
	params[18] = x__PMabiszBefiz__Dijbeido // gctr2
	x__PMabiszBefiz__Bizaz := make([]string, 0, 1000)
	params[19] = x__PMabiszBefiz__Bizaz // gctr2
	x__PMabiszBefiz__SzerzAzon := make([]int32, 0, 1000)
	params[16] = x__PMabiszBefiz__SzerzAzon // gctr2
	params[7] = output.PBaladoAdoelvar      // gcs1
	params[8] = output.PBaladoAdobefiz      // gcs1
	params[9] = output.PBaladoFinAdotartoz  // gcs1
	params[10] = output.PHibaKod            // gcs1
	params[11] = output.PHibaSzov           // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_egyeb_dijak(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_rendszam=>:p_rendszam,
		p_elvi_dijhatralek=>:p_elvi_dijhatralek,
		p_elmaradt_dij_befiz=>v001,
		p_mabisz_hatalytol=>:p_mabisz_hatalytol,
		p_mabisz_hatalyig=>:p_mabisz_hatalyig,
		p_mabisz_elvaras=>:p_mabisz_elvaras,
		p_mabisz_befiz=>v007,
		p_balado_adoelvar=>:p_balado_adoelvar,
		p_balado_adobefiz=>:p_balado_adobefiz,
		p_balado_fin_adotartoz=>:p_balado_fin_adotartoz,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_egyeb_dijak__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PElmaradtDijBefiz == nil { // *Db_dealer__dijtabla_rec_typ__bruno
		output.PElmaradtDijBefiz = make([]*DbDealer_DijtablaRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PElmaradtDijBefiz__SzerzAzon) - cap(output.PElmaradtDijBefiz); m > 0 {
		output.PElmaradtDijBefiz = append(output.PElmaradtDijBefiz, make([]*DbDealer_DijtablaRecTyp_Bruno, m)...)
	}
	output.PElmaradtDijBefiz = output.PElmaradtDijBefiz[:len(x__PElmaradtDijBefiz__SzerzAzon)]
	for i, v := range x__PElmaradtDijBefiz__SzerzAzon {
		if output.PElmaradtDijBefiz[i] != nil {
			output.PElmaradtDijBefiz[i].SzerzAzon = v
		}
	}
	if m := len(x__PElmaradtDijBefiz__Osszeg) - cap(output.PElmaradtDijBefiz); m > 0 {
		output.PElmaradtDijBefiz = append(output.PElmaradtDijBefiz, make([]*DbDealer_DijtablaRecTyp_Bruno, m)...)
	}
	output.PElmaradtDijBefiz = output.PElmaradtDijBefiz[:len(x__PElmaradtDijBefiz__Osszeg)]
	for i, v := range x__PElmaradtDijBefiz__Osszeg {
		if output.PElmaradtDijBefiz[i] != nil {
			output.PElmaradtDijBefiz[i].Osszeg = v
		}
	}
	if m := len(x__PElmaradtDijBefiz__Dijbeido) - cap(output.PElmaradtDijBefiz); m > 0 {
		output.PElmaradtDijBefiz = append(output.PElmaradtDijBefiz, make([]*DbDealer_DijtablaRecTyp_Bruno, m)...)
	}
	output.PElmaradtDijBefiz = output.PElmaradtDijBefiz[:len(x__PElmaradtDijBefiz__Dijbeido)]
	for i, v := range x__PElmaradtDijBefiz__Dijbeido {
		if output.PElmaradtDijBefiz[i] != nil {
			output.PElmaradtDijBefiz[i].Dijbeido = v
		}
	}
	if m := len(x__PElmaradtDijBefiz__Bizaz) - cap(output.PElmaradtDijBefiz); m > 0 {
		output.PElmaradtDijBefiz = append(output.PElmaradtDijBefiz, make([]*DbDealer_DijtablaRecTyp_Bruno, m)...)
	}
	output.PElmaradtDijBefiz = output.PElmaradtDijBefiz[:len(x__PElmaradtDijBefiz__Bizaz)]
	for i, v := range x__PElmaradtDijBefiz__Bizaz {
		if output.PElmaradtDijBefiz[i] != nil {
			output.PElmaradtDijBefiz[i].Bizaz = v
		}
	}

	if output.PMabiszBefiz == nil { // *Db_dealer__dijtabla_rec_typ__bruno
		output.PMabiszBefiz = make([]*DbDealer_DijtablaRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PMabiszBefiz__Osszeg) - cap(output.PMabiszBefiz); m > 0 {
		output.PMabiszBefiz = append(output.PMabiszBefiz, make([]*DbDealer_DijtablaRecTyp_Bruno, m)...)
	}
	output.PMabiszBefiz = output.PMabiszBefiz[:len(x__PMabiszBefiz__Osszeg)]
	for i, v := range x__PMabiszBefiz__Osszeg {
		if output.PMabiszBefiz[i] != nil {
			output.PMabiszBefiz[i].Osszeg = v
		}
	}
	if m := len(x__PMabiszBefiz__Dijbeido) - cap(output.PMabiszBefiz); m > 0 {
		output.PMabiszBefiz = append(output.PMabiszBefiz, make([]*DbDealer_DijtablaRecTyp_Bruno, m)...)
	}
	output.PMabiszBefiz = output.PMabiszBefiz[:len(x__PMabiszBefiz__Dijbeido)]
	for i, v := range x__PMabiszBefiz__Dijbeido {
		if output.PMabiszBefiz[i] != nil {
			output.PMabiszBefiz[i].Dijbeido = v
		}
	}
	if m := len(x__PMabiszBefiz__Bizaz) - cap(output.PMabiszBefiz); m > 0 {
		output.PMabiszBefiz = append(output.PMabiszBefiz, make([]*DbDealer_DijtablaRecTyp_Bruno, m)...)
	}
	output.PMabiszBefiz = output.PMabiszBefiz[:len(x__PMabiszBefiz__Bizaz)]
	for i, v := range x__PMabiszBefiz__Bizaz {
		if output.PMabiszBefiz[i] != nil {
			output.PMabiszBefiz[i].Bizaz = v
		}
	}
	if m := len(x__PMabiszBefiz__SzerzAzon) - cap(output.PMabiszBefiz); m > 0 {
		output.PMabiszBefiz = append(output.PMabiszBefiz, make([]*DbDealer_DijtablaRecTyp_Bruno, m)...)
	}
	output.PMabiszBefiz = output.PMabiszBefiz[:len(x__PMabiszBefiz__SzerzAzon)]
	for i, v := range x__PMabiszBefiz__SzerzAzon {
		if output.PMabiszBefiz[i] != nil {
			output.PMabiszBefiz[i].SzerzAzon = v
		}
	}

	return
}
const Db_dealer__szerzodes_dijrend__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.szerzodes_dijrend(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_datum=>:3,
		p_rendszam=>:4,
		p_hiba_kod=>:5,
		p_hiba_szov=>:6,
		p_dijrend=>:7,
		contract_balance_actualdate=>:8,
		mabisz_elvaras=>:9,
		tagdij_elvaras=>:10,
		elvi_dijhatralek=>:11);


END;
`

func (s *oracallServer) DbDealer_SzerzodesDijrend(ctx context.Context, input *DbDealer_SzerzodesDijrend_Input) (output *DbDealer_SzerzodesDijrend_Output, err error) {
	params := make([]interface{}, 11)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	output.PDatum = input.PDatum
	params[2] = output.PDatum                    // gcs1
	params[3] = input.PRendszam                  // gcs2
	params[4] = output.PHibaKod                  // gcs1
	params[5] = output.PHibaSzov                 // gcs1
	params[6] = output.PDijrend                  // gcs1
	params[7] = output.ContractBalanceActualdate // gcs1
	params[8] = output.MabiszElvaras             // gcs1
	params[9] = output.TagdijElvaras             // gcs1
	params[10] = output.ElviDijhatralek          // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_dijrend(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_datum=>:p_datum,
		p_rendszam=>:p_rendszam,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_dijrend=>:p_dijrend,
		contract_balance_actualdate=>:contract_balance_actualdate,
		mabisz_elvaras=>:mabisz_elvaras,
		tagdij_elvaras=>:tagdij_elvaras,
		elvi_dijhatralek=>:elvi_dijhatralek)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_dijrend__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_dijigazolas__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.szerzodes_dijigazolas(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_rendszam=>:3,
		p_hataly=>:4,
		client_name=>:5,
		client_birthdate=>:6,
		client_addr_pcode=>:7,
		client_addr_city=>:8,
		client_addr_street=>:9,
		client_taxnumber=>:10,
		client_certificatenumber=>:11,
		car_plate=>:12,
		car_category_letter=>:13,
		car_category=>:14,
		car_make=>:15,
		car_model=>:16,
		car_chassisnumber=>:17,
		p_kockezd=>:18,
		p_dijrend=>:19,
		p_balado_rend=>:20,
		p_anyanev=>:21,
		p_szulhely=>:22,
		p_ado_azonosito=>:23,
		p_dijfizgyak=>:24,
		p_evfordulo=>:25,
		p_jovo_dijrend=>:26,
		p_hiba_kod=>:27,
		p_hiba_szov=>:28);


END;
`

func (s *oracallServer) DbDealer_SzerzodesDijigazolas(ctx context.Context, input *DbDealer_SzerzodesDijigazolas_Input) (output *DbDealer_SzerzodesDijigazolas_Output, err error) {
	params := make([]interface{}, 28)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	params[2] = input.PRendszam  // gcs2
	output.PHataly = input.PHataly
	params[3] = output.PHataly                  // gcs1
	params[4] = output.ClientName               // gcs1
	params[5] = output.ClientBirthdate          // gcs1
	params[6] = output.ClientAddrPcode          // gcs1
	params[7] = output.ClientAddrCity           // gcs1
	params[8] = output.ClientAddrStreet         // gcs1
	params[9] = output.ClientTaxnumber          // gcs1
	params[10] = output.ClientCertificatenumber // gcs1
	params[11] = output.CarPlate                // gcs1
	params[12] = output.CarCategoryLetter       // gcs1
	params[13] = output.CarCategory             // gcs1
	params[14] = output.CarMake                 // gcs1
	params[15] = output.CarModel                // gcs1
	params[16] = output.CarChassisnumber        // gcs1
	params[17] = output.PKockezd                // gcs1
	params[18] = output.PDijrend                // gcs1
	params[19] = output.PBaladoRend             // gcs1
	params[20] = output.PAnyanev                // gcs1
	params[21] = output.PSzulhely               // gcs1
	params[22] = output.PAdoAzonosito           // gcs1
	params[23] = output.PDijfizgyak             // gcs1
	params[24] = output.PEvfordulo              // gcs1
	params[25] = output.PJovoDijrend            // gcs1
	params[26] = output.PHibaKod                // gcs1
	params[27] = output.PHibaSzov               // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_dijigazolas(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_rendszam=>:p_rendszam,
		p_hataly=>:p_hataly,
		client_name=>:client_name,
		client_birthdate=>:client_birthdate,
		client_addr_pcode=>:client_addr_pcode,
		client_addr_city=>:client_addr_city,
		client_addr_street=>:client_addr_street,
		client_taxnumber=>:client_taxnumber,
		client_certificatenumber=>:client_certificatenumber,
		car_plate=>:car_plate,
		car_category_letter=>:car_category_letter,
		car_category=>:car_category,
		car_make=>:car_make,
		car_model=>:car_model,
		car_chassisnumber=>:car_chassisnumber,
		p_kockezd=>:p_kockezd,
		p_dijrend=>:p_dijrend,
		p_balado_rend=>:p_balado_rend,
		p_anyanev=>:p_anyanev,
		p_szulhely=>:p_szulhely,
		p_ado_azonosito=>:p_ado_azonosito,
		p_dijfizgyak=>:p_dijfizgyak,
		p_evfordulo=>:p_evfordulo,
		p_jovo_dijrend=>:p_jovo_dijrend,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_dijigazolas__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__szerzodes_megszunestajekoztato__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.JARMU_ADAT_REC_TYP;
  v006 BRUNO.DB_DEALER.BIZT_REC_TYP;
  v010 BRUNO.DB_DEALER.SZUNET_TAB_TYP;
  TYPE DATE_tab_typ IS TABLE OF DATE INDEX BY BINARY_INTEGER;
  p011#kezd DATE_tab_typ;
  p011#veg DATE_tab_typ;
  v014 BRUNO.DB_DEALER.KAR_TAB_TYP;
  p015#kareset DATE_tab_typ;
  p015#elsokifiz DATE_tab_typ;
  TYPE VARCHAR2_4_tab_typ IS TABLE OF VARCHAR2(4) INDEX BY BINARY_INTEGER;
  p015#visszafiz VARCHAR2_4_tab_typ;
  p015#visszafiz_datum DATE_tab_typ;

BEGIN
  v010.DELETE;
  p011#kezd.DELETE;
  p011#veg.DELETE;
  v014.DELETE;
  p015#kareset.DELETE;
  p015#elsokifiz.DELETE;
  p015#visszafiz.DELETE;
  p015#visszafiz_datum.DELETE;

  DB_dealer.szerzodes_megszunestajekoztato(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4,
		p_url=>:5,
		p_level_vonalkod=>:6,
		p_szerzodo_nev=>:7,
		p_varos=>:8,
		p_utcanev=>:9,
		p_uttipus=>:10,
		p_hazszam=>:11,
		p_emelet_ajto=>:12,
		p_irszam=>:13,
		p_uzembentarto_nev=>:14,
		p_jarmu_adatok=>v001,
		p_kotvenyszam=>:15,
		p_kockezd=>:16,
		p_megszun_ok=>:17,
		p_megszun_idopont=>:18,
		p_dijrend=>:19,
		p_adorend=>:20,
		p_bizt_ev_vege=>:21,
		p_karmentes=>:22,
		p_bm_jelenleg=>:23,
		p_bm_kovetkezo=>:24,
		p_kiallitas_helye=>:25,
		p_keltezes=>:26,
		p_egyedi_dokazon=>:27,
		p_szerzodo_szuldat=>:28,
		p_anyanev=>:29,
		p_kartorteneti_azonosito=>:30,
		p_bizt_rec=>v006,
		p_szunet_tbl=>v010,
		p_kar_tbl=>v014);

  :31 := v001.rendszam;
  :32 := v001.alvazszam;
  :33 := v001.gjmu_kat;
  :34 := v006.nev;
  :35 := v006.cim;
  
  i1 := v010.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p011#kezd(i2) := v010(i1).kezd;
    p011#veg(i2) := v010(i1).veg;
    i1 := v010.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :36 := p011#kezd;
  :37 := p011#veg;
  
  i1 := v014.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p015#kareset(i2) := v014(i1).kareset;
    p015#elsokifiz(i2) := v014(i1).elsokifiz;
    p015#visszafiz(i2) := v014(i1).visszafiz;
    p015#visszafiz_datum(i2) := v014(i1).visszafiz_datum;
    i1 := v014.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :38 := p015#kareset;
  :39 := p015#elsokifiz;
  :40 := p015#visszafiz;
  :41 := p015#visszafiz_datum;

END;
`

func (s *oracallServer) DbDealer_SzerzodesMegszunestajekoztato(ctx context.Context, input *DbDealer_SzerzodesMegszunestajekoztato_Input) (output *DbDealer_SzerzodesMegszunestajekoztato_Output, err error) {
	params := make([]interface{}, 41)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon                   // gcs2
	params[1] = input.PSzerzAzon               // gcs2
	params[2] = output.PHibaKod                // gcs1
	params[3] = output.PHibaSzov               // gcs1
	params[4] = output.PUrl                    // gcs1
	params[5] = output.PLevelVonalkod          // gcs1
	params[6] = output.PSzerzodoNev            // gcs1
	params[7] = output.PVaros                  // gcs1
	params[8] = output.PUtcanev                // gcs1
	params[9] = output.PUttipus                // gcs1
	params[10] = output.PHazszam               // gcs1
	params[11] = output.PEmeletAjto            // gcs1
	params[12] = output.PIrszam                // gcs1
	params[13] = output.PUzembentartoNev       // gcs1
	params[30] = output.PJarmuAdatok.Rendszam  // gcr2
	params[31] = output.PJarmuAdatok.Alvazszam // gcr2
	params[32] = output.PJarmuAdatok.GjmuKat   // gcr2
	params[14] = output.PKotvenyszam           // gcs1
	params[15] = output.PKockezd               // gcs1
	params[16] = output.PMegszunOk             // gcs1
	params[17] = output.PMegszunIdopont        // gcs1
	params[18] = output.PDijrend               // gcs1
	params[19] = output.PAdorend               // gcs1
	params[20] = output.PBiztEvVege            // gcs1
	params[21] = output.PKarmentes             // gcs1
	params[22] = output.PBmJelenleg            // gcs1
	params[23] = output.PBmKovetkezo           // gcs1
	params[24] = output.PKiallitasHelye        // gcs1
	params[25] = output.PKeltezes              // gcs1
	params[26] = output.PEgyediDokazon         // gcs1
	params[27] = output.PSzerzodoSzuldat       // gcs1
	params[28] = output.PAnyanev               // gcs1
	params[29] = output.PKartortenetiAzonosito // gcs1
	params[33] = output.PBiztRec.Nev           // gcr2
	params[34] = output.PBiztRec.Cim           // gcr2
	x__PSzunetTbl__Kezd := make([]custom.Date, 0, 1000)
	params[35] = x__PSzunetTbl__Kezd // gctr2
	x__PSzunetTbl__Veg := make([]custom.Date, 0, 1000)
	params[36] = x__PSzunetTbl__Veg // gctr2
	x__PKarTbl__Kareset := make([]custom.Date, 0, 1000)
	params[37] = x__PKarTbl__Kareset // gctr2
	x__PKarTbl__Elsokifiz := make([]custom.Date, 0, 1000)
	params[38] = x__PKarTbl__Elsokifiz // gctr2
	x__PKarTbl__Visszafiz := make([]string, 0, 1000)
	params[39] = x__PKarTbl__Visszafiz // gctr2
	x__PKarTbl__VisszafizDatum := make([]custom.Date, 0, 1000)
	params[40] = x__PKarTbl__VisszafizDatum // gctr2

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_megszunestajekoztato(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_url=>:p_url,
		p_level_vonalkod=>:p_level_vonalkod,
		p_szerzodo_nev=>:p_szerzodo_nev,
		p_varos=>:p_varos,
		p_utcanev=>:p_utcanev,
		p_uttipus=>:p_uttipus,
		p_hazszam=>:p_hazszam,
		p_emelet_ajto=>:p_emelet_ajto,
		p_irszam=>:p_irszam,
		p_uzembentarto_nev=>:p_uzembentarto_nev,
		p_jarmu_adatok=>v001,
		p_kotvenyszam=>:p_kotvenyszam,
		p_kockezd=>:p_kockezd,
		p_megszun_ok=>:p_megszun_ok,
		p_megszun_idopont=>:p_megszun_idopont,
		p_dijrend=>:p_dijrend,
		p_adorend=>:p_adorend,
		p_bizt_ev_vege=>:p_bizt_ev_vege,
		p_karmentes=>:p_karmentes,
		p_bm_jelenleg=>:p_bm_jelenleg,
		p_bm_kovetkezo=>:p_bm_kovetkezo,
		p_kiallitas_helye=>:p_kiallitas_helye,
		p_keltezes=>:p_keltezes,
		p_egyedi_dokazon=>:p_egyedi_dokazon,
		p_szerzodo_szuldat=>:p_szerzodo_szuldat,
		p_anyanev=>:p_anyanev,
		p_kartorteneti_azonosito=>:p_kartorteneti_azonosito,
		p_bizt_rec=>v006,
		p_szunet_tbl=>v010,
		p_kar_tbl=>v014)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_megszunestajekoztato__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PJarmuAdatok == nil {
		output.PJarmuAdatok = new(DbDealer_JarmuAdatRecTyp_Bruno)
	}

	if output.PBiztRec == nil {
		output.PBiztRec = new(DbDealer_BiztRecTyp_Bruno)
	}

	if output.PSzunetTbl == nil { // *Db_dealer__szunet_rec_typ__bruno
		output.PSzunetTbl = make([]*DbDealer_SzunetRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PSzunetTbl__Kezd) - cap(output.PSzunetTbl); m > 0 {
		output.PSzunetTbl = append(output.PSzunetTbl, make([]*DbDealer_SzunetRecTyp_Bruno, m)...)
	}
	output.PSzunetTbl = output.PSzunetTbl[:len(x__PSzunetTbl__Kezd)]
	for i, v := range x__PSzunetTbl__Kezd {
		if output.PSzunetTbl[i] != nil {
			output.PSzunetTbl[i].Kezd = v
		}
	}
	if m := len(x__PSzunetTbl__Veg) - cap(output.PSzunetTbl); m > 0 {
		output.PSzunetTbl = append(output.PSzunetTbl, make([]*DbDealer_SzunetRecTyp_Bruno, m)...)
	}
	output.PSzunetTbl = output.PSzunetTbl[:len(x__PSzunetTbl__Veg)]
	for i, v := range x__PSzunetTbl__Veg {
		if output.PSzunetTbl[i] != nil {
			output.PSzunetTbl[i].Veg = v
		}
	}

	if output.PKarTbl == nil { // *Db_dealer__kar_rec_typ__bruno
		output.PKarTbl = make([]*DbDealer_KarRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PKarTbl__Kareset) - cap(output.PKarTbl); m > 0 {
		output.PKarTbl = append(output.PKarTbl, make([]*DbDealer_KarRecTyp_Bruno, m)...)
	}
	output.PKarTbl = output.PKarTbl[:len(x__PKarTbl__Kareset)]
	for i, v := range x__PKarTbl__Kareset {
		if output.PKarTbl[i] != nil {
			output.PKarTbl[i].Kareset = v
		}
	}
	if m := len(x__PKarTbl__Elsokifiz) - cap(output.PKarTbl); m > 0 {
		output.PKarTbl = append(output.PKarTbl, make([]*DbDealer_KarRecTyp_Bruno, m)...)
	}
	output.PKarTbl = output.PKarTbl[:len(x__PKarTbl__Elsokifiz)]
	for i, v := range x__PKarTbl__Elsokifiz {
		if output.PKarTbl[i] != nil {
			output.PKarTbl[i].Elsokifiz = v
		}
	}
	if m := len(x__PKarTbl__Visszafiz) - cap(output.PKarTbl); m > 0 {
		output.PKarTbl = append(output.PKarTbl, make([]*DbDealer_KarRecTyp_Bruno, m)...)
	}
	output.PKarTbl = output.PKarTbl[:len(x__PKarTbl__Visszafiz)]
	for i, v := range x__PKarTbl__Visszafiz {
		if output.PKarTbl[i] != nil {
			output.PKarTbl[i].Visszafiz = v
		}
	}
	if m := len(x__PKarTbl__VisszafizDatum) - cap(output.PKarTbl); m > 0 {
		output.PKarTbl = append(output.PKarTbl, make([]*DbDealer_KarRecTyp_Bruno, m)...)
	}
	output.PKarTbl = output.PKarTbl[:len(x__PKarTbl__VisszafizDatum)]
	for i, v := range x__PKarTbl__VisszafizDatum {
		if output.PKarTbl[i] != nil {
			output.PKarTbl[i].VisszafizDatum = v
		}
	}

	return
}
const Db_dealer__szerzodes_kedvezmenyek__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER_KOZOS.RESZL_TAB_TYP;
  TYPE VARCHAR2_40_tab_typ IS TABLE OF VARCHAR2(40) INDEX BY BINARY_INTEGER;
  p002#modnev VARCHAR2_40_tab_typ;
  TYPE NUMBER_9_tab_typ IS TABLE OF NUMBER(9) INDEX BY BINARY_INTEGER;
  p002#evesdij NUMBER_9_tab_typ;
  TYPE NUMBER_5_2_tab_typ IS TABLE OF NUMBER(5, 2) INDEX BY BINARY_INTEGER;
  p002#szazalek NUMBER_5_2_tab_typ;
  TYPE VARCHAR2_6_tab_typ IS TABLE OF VARCHAR2(6) INDEX BY BINARY_INTEGER;
  p002#modkod VARCHAR2_6_tab_typ;
  v007 BRUNO.DB_DEALER_KOZOS.RESZL_TAB_TYP;
  p008#modnev VARCHAR2_40_tab_typ;
  p008#evesdij NUMBER_9_tab_typ;
  p008#szazalek NUMBER_5_2_tab_typ;
  p008#modkod VARCHAR2_6_tab_typ;

BEGIN
  v001.DELETE;
  p002#modnev.DELETE;
  p002#evesdij.DELETE;
  p002#szazalek.DELETE;
  p002#modkod.DELETE;
  v007.DELETE;
  p008#modnev.DELETE;
  p008#evesdij.DELETE;
  p008#szazalek.DELETE;
  p008#modkod.DELETE;

  DB_dealer.szerzodes_kedvezmenyek(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_kedv_aktualis=>v001,
		p_kedv_indexalt=>v007,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#evesdij(i2) := v001(i1).evesdij;
    p002#szazalek(i2) := v001(i1).szazalek;
    p002#modkod(i2) := v001(i1).modkod;
    p002#modnev(i2) := v001(i1).modnev;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :5 := p002#szazalek;
  :6 := p002#modkod;
  :7 := p002#modnev;
  :8 := p002#evesdij;
  
  i1 := v007.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p008#evesdij(i2) := v007(i1).evesdij;
    p008#szazalek(i2) := v007(i1).szazalek;
    p008#modkod(i2) := v007(i1).modkod;
    p008#modnev(i2) := v007(i1).modnev;
    i1 := v007.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :9 := p008#modkod;
  :10 := p008#modnev;
  :11 := p008#evesdij;
  :12 := p008#szazalek;

END;
`

func (s *oracallServer) DbDealer_SzerzodesKedvezmenyek(ctx context.Context, input *DbDealer_SzerzodesKedvezmenyek_Input) (output *DbDealer_SzerzodesKedvezmenyek_Output, err error) {
	params := make([]interface{}, 12)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	x__PKedvAktualis__Evesdij := make([]float64, 0, 1000)
	params[7] = x__PKedvAktualis__Evesdij // gctr2
	x__PKedvAktualis__Szazalek := make([]float64, 0, 1000)
	params[4] = x__PKedvAktualis__Szazalek // gctr2
	x__PKedvAktualis__Modkod := make([]string, 0, 1000)
	params[5] = x__PKedvAktualis__Modkod // gctr2
	x__PKedvAktualis__Modnev := make([]string, 0, 1000)
	params[6] = x__PKedvAktualis__Modnev // gctr2
	x__PKedvIndexalt__Evesdij := make([]float64, 0, 1000)
	params[10] = x__PKedvIndexalt__Evesdij // gctr2
	x__PKedvIndexalt__Szazalek := make([]float64, 0, 1000)
	params[11] = x__PKedvIndexalt__Szazalek // gctr2
	x__PKedvIndexalt__Modkod := make([]string, 0, 1000)
	params[8] = x__PKedvIndexalt__Modkod // gctr2
	x__PKedvIndexalt__Modnev := make([]string, 0, 1000)
	params[9] = x__PKedvIndexalt__Modnev // gctr2
	params[2] = output.PHibaKod          // gcs1
	params[3] = output.PHibaSzov         // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.szerzodes_kedvezmenyek(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_kedv_aktualis=>v001,
		p_kedv_indexalt=>v007,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__szerzodes_kedvezmenyek__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PKedvAktualis == nil { // *Db_dealer_kozos__reszl_rec_typ__bruno
		output.PKedvAktualis = make([]*DbDealerKozos_ReszlRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PKedvAktualis__Evesdij) - cap(output.PKedvAktualis); m > 0 {
		output.PKedvAktualis = append(output.PKedvAktualis, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PKedvAktualis = output.PKedvAktualis[:len(x__PKedvAktualis__Evesdij)]
	for i, v := range x__PKedvAktualis__Evesdij {
		if output.PKedvAktualis[i] != nil {
			output.PKedvAktualis[i].Evesdij = v
		}
	}
	if m := len(x__PKedvAktualis__Szazalek) - cap(output.PKedvAktualis); m > 0 {
		output.PKedvAktualis = append(output.PKedvAktualis, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PKedvAktualis = output.PKedvAktualis[:len(x__PKedvAktualis__Szazalek)]
	for i, v := range x__PKedvAktualis__Szazalek {
		if output.PKedvAktualis[i] != nil {
			output.PKedvAktualis[i].Szazalek = v
		}
	}
	if m := len(x__PKedvAktualis__Modkod) - cap(output.PKedvAktualis); m > 0 {
		output.PKedvAktualis = append(output.PKedvAktualis, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PKedvAktualis = output.PKedvAktualis[:len(x__PKedvAktualis__Modkod)]
	for i, v := range x__PKedvAktualis__Modkod {
		if output.PKedvAktualis[i] != nil {
			output.PKedvAktualis[i].Modkod = v
		}
	}
	if m := len(x__PKedvAktualis__Modnev) - cap(output.PKedvAktualis); m > 0 {
		output.PKedvAktualis = append(output.PKedvAktualis, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PKedvAktualis = output.PKedvAktualis[:len(x__PKedvAktualis__Modnev)]
	for i, v := range x__PKedvAktualis__Modnev {
		if output.PKedvAktualis[i] != nil {
			output.PKedvAktualis[i].Modnev = v
		}
	}

	if output.PKedvIndexalt == nil { // *Db_dealer_kozos__reszl_rec_typ__bruno
		output.PKedvIndexalt = make([]*DbDealerKozos_ReszlRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PKedvIndexalt__Evesdij) - cap(output.PKedvIndexalt); m > 0 {
		output.PKedvIndexalt = append(output.PKedvIndexalt, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PKedvIndexalt = output.PKedvIndexalt[:len(x__PKedvIndexalt__Evesdij)]
	for i, v := range x__PKedvIndexalt__Evesdij {
		if output.PKedvIndexalt[i] != nil {
			output.PKedvIndexalt[i].Evesdij = v
		}
	}
	if m := len(x__PKedvIndexalt__Szazalek) - cap(output.PKedvIndexalt); m > 0 {
		output.PKedvIndexalt = append(output.PKedvIndexalt, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PKedvIndexalt = output.PKedvIndexalt[:len(x__PKedvIndexalt__Szazalek)]
	for i, v := range x__PKedvIndexalt__Szazalek {
		if output.PKedvIndexalt[i] != nil {
			output.PKedvIndexalt[i].Szazalek = v
		}
	}
	if m := len(x__PKedvIndexalt__Modkod) - cap(output.PKedvIndexalt); m > 0 {
		output.PKedvIndexalt = append(output.PKedvIndexalt, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PKedvIndexalt = output.PKedvIndexalt[:len(x__PKedvIndexalt__Modkod)]
	for i, v := range x__PKedvIndexalt__Modkod {
		if output.PKedvIndexalt[i] != nil {
			output.PKedvIndexalt[i].Modkod = v
		}
	}
	if m := len(x__PKedvIndexalt__Modnev) - cap(output.PKedvIndexalt); m > 0 {
		output.PKedvIndexalt = append(output.PKedvIndexalt, make([]*DbDealerKozos_ReszlRecTyp_Bruno, m)...)
	}
	output.PKedvIndexalt = output.PKedvIndexalt[:len(x__PKedvIndexalt__Modnev)]
	for i, v := range x__PKedvIndexalt__Modnev {
		if output.PKedvIndexalt[i] != nil {
			output.PKedvIndexalt[i].Modnev = v
		}
	}

	return
}
const Db_dealer__dij_szamitas__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.dij_szamitas(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_datum_tol=>:3,
		p_datum_ig=>:4,
		p_hiba_kod=>:5,
		p_hiba_szov=>:6,
		p_dij=>:7);


END;
`

func (s *oracallServer) DbDealer_DijSzamitas(ctx context.Context, input *DbDealer_DijSzamitas_Input) (output *DbDealer_DijSzamitas_Output, err error) {
	params := make([]interface{}, 7)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	output.PDatumTol = input.PDatumTol
	params[2] = output.PDatumTol // gcs1
	output.PDatumIg = input.PDatumIg
	params[3] = output.PDatumIg  // gcs1
	params[4] = output.PHibaKod  // gcs1
	params[5] = output.PHibaSzov // gcs1
	params[6] = output.PDij      // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.dij_szamitas(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_datum_tol=>:p_datum_tol,
		p_datum_ig=>:p_datum_ig,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_dij=>:p_dij)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__dij_szamitas__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__csekk_nyomtatas__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER_KOZOS.NAPIDIJ_TAB_TYP;
  TYPE DATE_tab_typ IS TABLE OF DATE INDEX BY BINARY_INTEGER;
  p002#hatalytol DATE_tab_typ;
  TYPE NUMBER_tab_typ IS TABLE OF NUMBER INDEX BY BINARY_INTEGER;
  p002#osszeg NUMBER_tab_typ;

BEGIN
  v001.DELETE;
  p002#hatalytol.DELETE;
  p002#osszeg.DELETE;

  DB_dealer.csekk_nyomtatas(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_rendszam=>:3,
		p_csekk_tipus=>:4,
		p_datum_tol=>:5,
		p_datum_ig=>:6,
		p_elonezet=>:7,
		p_befiz_osszeg=>:8,
		p_befiz_datum=>:9,
		p_tagdij_nelkul=>:10,
		p_hiba_kod=>:11,
		p_hiba_szov=>:12,
		p_dij=>:13,
		p_dij_gfb=>:14,
		p_dij_mabisz=>:15,
		p_elmaradt=>:16,
		p_e_szerz_azon=>:17,
		p_dij_tag=>:18,
		p_balado=>:19,
		p_adoegyenleg=>:20,
		p_adorend=>:21,
		p_befizaz=>:22,
		p_szelveny=>:23,
		p_megjegyzes=>:24,
		p_ugyfelnev=>:25,
		p_irszam=>:26,
		p_telepules=>:27,
		p_cim=>:28,
		p_dijhalaszt=>:29,
		p_elvi_kockvege=>:30,
		p_napidijak=>v001,
		p_csekk_azon=>:31);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#hatalytol(i2) := v001(i1).hatalytol;
    p002#osszeg(i2) := v001(i1).osszeg;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :32 := p002#hatalytol;
  :33 := p002#osszeg;

END;
`

func (s *oracallServer) DbDealer_CsekkNyomtatas(ctx context.Context, input *DbDealer_CsekkNyomtatas_Input) (output *DbDealer_CsekkNyomtatas_Output, err error) {
	params := make([]interface{}, 33)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon      // gcs2
	params[1] = input.PSzerzAzon  // gcs2
	params[2] = input.PRendszam   // gcs2
	params[3] = input.PCsekkTipus // gcs2
	output.PDatumTol = input.PDatumTol
	params[4] = output.PDatumTol // gcs1
	output.PDatumIg = input.PDatumIg
	params[5] = output.PDatumIg       // gcs1
	params[6] = input.PElonezet       // gcs2
	params[7] = input.PBefizOsszeg    // gcs2
	params[8] = input.PBefizDatum     // gcs2
	params[9] = input.PTagdijNelkul   // gcs2
	params[10] = output.PHibaKod      // gcs1
	params[11] = output.PHibaSzov     // gcs1
	params[12] = output.PDij          // gcs1
	params[13] = output.PDijGfb       // gcs1
	params[14] = output.PDijMabisz    // gcs1
	params[15] = output.PElmaradt     // gcs1
	params[16] = output.PESzerzAzon   // gcs1
	params[17] = output.PDijTag       // gcs1
	params[18] = output.PBalado       // gcs1
	params[19] = output.PAdoegyenleg  // gcs1
	params[20] = output.PAdorend      // gcs1
	params[21] = output.PBefizaz      // gcs1
	params[22] = output.PSzelveny     // gcs1
	params[23] = output.PMegjegyzes   // gcs1
	params[24] = output.PUgyfelnev    // gcs1
	params[25] = output.PIrszam       // gcs1
	params[26] = output.PTelepules    // gcs1
	params[27] = output.PCim          // gcs1
	params[28] = output.PDijhalaszt   // gcs1
	params[29] = output.PElviKockvege // gcs1
	x__PNapidijak__Hatalytol := make([]custom.Date, 0, 1000)
	params[31] = x__PNapidijak__Hatalytol // gctr2
	x__PNapidijak__Osszeg := make([]float64, 0, 1000)
	params[32] = x__PNapidijak__Osszeg // gctr2
	params[30] = output.PCsekkAzon     // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.csekk_nyomtatas(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_rendszam=>:p_rendszam,
		p_csekk_tipus=>:p_csekk_tipus,
		p_datum_tol=>:p_datum_tol,
		p_datum_ig=>:p_datum_ig,
		p_elonezet=>:p_elonezet,
		p_befiz_osszeg=>:p_befiz_osszeg,
		p_befiz_datum=>:p_befiz_datum,
		p_tagdij_nelkul=>:p_tagdij_nelkul,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_dij=>:p_dij,
		p_dij_gfb=>:p_dij_gfb,
		p_dij_mabisz=>:p_dij_mabisz,
		p_elmaradt=>:p_elmaradt,
		p_e_szerz_azon=>:p_e_szerz_azon,
		p_dij_tag=>:p_dij_tag,
		p_balado=>:p_balado,
		p_adoegyenleg=>:p_adoegyenleg,
		p_adorend=>:p_adorend,
		p_befizaz=>:p_befizaz,
		p_szelveny=>:p_szelveny,
		p_megjegyzes=>:p_megjegyzes,
		p_ugyfelnev=>:p_ugyfelnev,
		p_irszam=>:p_irszam,
		p_telepules=>:p_telepules,
		p_cim=>:p_cim,
		p_dijhalaszt=>:p_dijhalaszt,
		p_elvi_kockvege=>:p_elvi_kockvege,
		p_napidijak=>v001,
		p_csekk_azon=>:p_csekk_azon)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__csekk_nyomtatas__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PNapidijak == nil { // *Db_dealer_kozos__napidij_rec_typ__bruno
		output.PNapidijak = make([]*DbDealerKozos_NapidijRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PNapidijak__Hatalytol) - cap(output.PNapidijak); m > 0 {
		output.PNapidijak = append(output.PNapidijak, make([]*DbDealerKozos_NapidijRecTyp_Bruno, m)...)
	}
	output.PNapidijak = output.PNapidijak[:len(x__PNapidijak__Hatalytol)]
	for i, v := range x__PNapidijak__Hatalytol {
		if output.PNapidijak[i] != nil {
			output.PNapidijak[i].Hatalytol = v
		}
	}
	if m := len(x__PNapidijak__Osszeg) - cap(output.PNapidijak); m > 0 {
		output.PNapidijak = append(output.PNapidijak, make([]*DbDealerKozos_NapidijRecTyp_Bruno, m)...)
	}
	output.PNapidijak = output.PNapidijak[:len(x__PNapidijak__Osszeg)]
	for i, v := range x__PNapidijak__Osszeg {
		if output.PNapidijak[i] != nil {
			output.PNapidijak[i].Osszeg = v
		}
	}

	return
}
const Db_dealer__zkty_nyomtatas__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.zkty_nyomtatas(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_elonezet=>:3,
		p_hiba_kod=>:4,
		p_hiba_szov=>:5,
		p_zkty_azon=>:6,
		green_valid_from=>:7,
		green_valid_to=>:8);


END;
`

func (s *oracallServer) DbDealer_ZktyNyomtatas(ctx context.Context, input *DbDealer_ZktyNyomtatas_Input) (output *DbDealer_ZktyNyomtatas_Output, err error) {
	params := make([]interface{}, 8)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon          // gcs2
	params[1] = input.PSzerzAzon      // gcs2
	params[2] = input.PElonezet       // gcs2
	params[3] = output.PHibaKod       // gcs1
	params[4] = output.PHibaSzov      // gcs1
	params[5] = output.PZktyAzon      // gcs1
	params[6] = output.GreenValidFrom // gcs1
	params[7] = output.GreenValidTo   // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.zkty_nyomtatas(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_elonezet=>:p_elonezet,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_zkty_azon=>:p_zkty_azon,
		green_valid_from=>:green_valid_from,
		green_valid_to=>:green_valid_to)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__zkty_nyomtatas__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__zkty_spec_keres__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.zkty_spec_keres(p_bazon=>:1,
		p_vonalkod=>:2,
		p_szerz_azon=>:3,
		p_rendszam=>:4,
		p_hiba_kod=>:5,
		p_hiba_szov=>:6,
		p_ugyfelnev=>:7,
		contract_status_short=>:8,
		p_dijrend=>:9);


END;
`

func (s *oracallServer) DbDealer_ZktySpecKeres(ctx context.Context, input *DbDealer_ZktySpecKeres_Input) (output *DbDealer_ZktySpecKeres_Output, err error) {
	params := make([]interface{}, 9)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon    // gcs2
	params[1] = input.PVonalkod // gcs2
	output.PSzerzAzon = input.PSzerzAzon
	params[2] = output.PSzerzAzon          // gcs1
	params[3] = input.PRendszam            // gcs2
	params[4] = output.PHibaKod            // gcs1
	params[5] = output.PHibaSzov           // gcs1
	params[6] = output.PUgyfelnev          // gcs1
	params[7] = output.ContractStatusShort // gcs1
	params[8] = output.PDijrend            // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.zkty_spec_keres(p_bazon=>:p_bazon,
		p_vonalkod=>:p_vonalkod,
		p_szerz_azon=>:p_szerz_azon,
		p_rendszam=>:p_rendszam,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_ugyfelnev=>:p_ugyfelnev,
		contract_status_short=>:contract_status_short,
		p_dijrend=>:p_dijrend)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__zkty_spec_keres__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__spec_keres__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.spec_keres(p_bazon=>:1,
		p_vonalkod=>:2,
		p_szerz_azon=>:3,
		p_rendszam=>:4,
		p_hiba_kod=>:5,
		p_hiba_szov=>:6,
		p_ugyfelnev=>:7,
		contract_status_short=>:8,
		p_dijrend=>:9);


END;
`

func (s *oracallServer) DbDealer_SpecKeres(ctx context.Context, input *DbDealer_SpecKeres_Input) (output *DbDealer_SpecKeres_Output, err error) {
	params := make([]interface{}, 9)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon    // gcs2
	params[1] = input.PVonalkod // gcs2
	output.PSzerzAzon = input.PSzerzAzon
	params[2] = output.PSzerzAzon          // gcs1
	params[3] = input.PRendszam            // gcs2
	params[4] = output.PHibaKod            // gcs1
	params[5] = output.PHibaSzov           // gcs1
	params[6] = output.PUgyfelnev          // gcs1
	params[7] = output.ContractStatusShort // gcs1
	params[8] = output.PDijrend            // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.spec_keres(p_bazon=>:p_bazon,
		p_vonalkod=>:p_vonalkod,
		p_szerz_azon=>:p_szerz_azon,
		p_rendszam=>:p_rendszam,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_ugyfelnev=>:p_ugyfelnev,
		contract_status_short=>:contract_status_short,
		p_dijrend=>:p_dijrend)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__spec_keres__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__zkty_spec_nyomtatas__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.zkty_spec_nyomtatas(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_befiz_osszeg=>:3,
		p_befiz_datum=>:4,
		p_elonezet=>:5,
		p_hiba_kod=>:6,
		p_hiba_szov=>:7,
		p_zkty_azon=>:8,
		client_name=>:9,
		client_addr_pcode=>:10,
		client_addr_city=>:11,
		client_addr_street=>:12,
		car_plate=>:13,
		car_category_letter=>:14,
		car_make=>:15,
		green_valid_from=>:16,
		green_valid_to=>:17);


END;
`

func (s *oracallServer) DbDealer_ZktySpecNyomtatas(ctx context.Context, input *DbDealer_ZktySpecNyomtatas_Input) (output *DbDealer_ZktySpecNyomtatas_Output, err error) {
	params := make([]interface{}, 17)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon              // gcs2
	params[1] = input.PSzerzAzon          // gcs2
	params[2] = input.PBefizOsszeg        // gcs2
	params[3] = input.PBefizDatum         // gcs2
	params[4] = input.PElonezet           // gcs2
	params[5] = output.PHibaKod           // gcs1
	params[6] = output.PHibaSzov          // gcs1
	params[7] = output.PZktyAzon          // gcs1
	params[8] = output.ClientName         // gcs1
	params[9] = output.ClientAddrPcode    // gcs1
	params[10] = output.ClientAddrCity    // gcs1
	params[11] = output.ClientAddrStreet  // gcs1
	params[12] = output.CarPlate          // gcs1
	params[13] = output.CarCategoryLetter // gcs1
	params[14] = output.CarMake           // gcs1
	params[15] = output.GreenValidFrom    // gcs1
	params[16] = output.GreenValidTo      // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.zkty_spec_nyomtatas(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_befiz_osszeg=>:p_befiz_osszeg,
		p_befiz_datum=>:p_befiz_datum,
		p_elonezet=>:p_elonezet,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov,
		p_zkty_azon=>:p_zkty_azon,
		client_name=>:client_name,
		client_addr_pcode=>:client_addr_pcode,
		client_addr_city=>:client_addr_city,
		client_addr_street=>:client_addr_street,
		car_plate=>:car_plate,
		car_category_letter=>:car_category_letter,
		car_make=>:car_make,
		green_valid_from=>:green_valid_from,
		green_valid_to=>:green_valid_to)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__zkty_spec_nyomtatas__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__login__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.login(p_login_nev=>:1,
		p_jelszo=>:2,
		p_addr=>:3,
		p_bazon=>:4,
		p_torzsszam=>:5,
		p_hiba_kod=>:6,
		p_hiba_szov=>:7);


END;
`

func (s *oracallServer) DbDealer_Login(ctx context.Context, input *DbDealer_Login_Input) (output *DbDealer_Login_Output, err error) {
	params := make([]interface{}, 7)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PLoginNev   // gcs2
	params[1] = input.PJelszo     // gcs2
	params[2] = input.PAddr       // gcs2
	params[3] = output.PBazon     // gcs1
	params[4] = output.PTorzsszam // gcs1
	params[5] = output.PHibaKod   // gcs1
	params[6] = output.PHibaSzov  // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.login(p_login_nev=>:p_login_nev,
		p_jelszo=>:p_jelszo,
		p_addr=>:p_addr,
		p_bazon=>:p_bazon,
		p_torzsszam=>:p_torzsszam,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__login__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__logout__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.logout(p_bazon=>:1,
		p_hiba_kod=>:2,
		p_hiba_szov=>:3);


END;
`

func (s *oracallServer) DbDealer_Logout(ctx context.Context, input *DbDealer_Logout_Input) (output *DbDealer_Logout_Output, err error) {
	params := make([]interface{}, 3)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = output.PHibaKod  // gcs1
	params[2] = output.PHibaSzov // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.logout(p_bazon=>:p_bazon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__logout__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__login_jelszo_valt__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.login_jelszo_valt(p_bazon=>:1,
		p_login_nev=>:2,
		p_jelszo_regi=>:3,
		p_jelszo_uj=>:4,
		p_hiba_kod=>:5,
		p_hiba_szov=>:6);


END;
`

func (s *oracallServer) DbDealer_LoginJelszoValt(ctx context.Context, input *DbDealer_LoginJelszoValt_Input) (output *DbDealer_LoginJelszoValt_Output, err error) {
	params := make([]interface{}, 6)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon      // gcs2
	params[1] = input.PLoginNev   // gcs2
	params[2] = input.PJelszoRegi // gcs2
	params[3] = input.PJelszoUj   // gcs2
	params[4] = output.PHibaKod   // gcs1
	params[5] = output.PHibaSzov  // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.login_jelszo_valt(p_bazon=>:p_bazon,
		p_login_nev=>:p_login_nev,
		p_jelszo_regi=>:p_jelszo_regi,
		p_jelszo_uj=>:p_jelszo_uj,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__login_jelszo_valt__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__bazon_ok__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.bazon_ok(p_bazon=>:1,
		p_hiba_kod=>:2,
		p_hiba_szov=>:3);


END;
`

func (s *oracallServer) DbDealer_BazonOk(ctx context.Context, input *DbDealer_BazonOk_Input) (output *DbDealer_BazonOk_Output, err error) {
	params := make([]interface{}, 3)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = output.PHibaKod  // gcs1
	params[2] = output.PHibaSzov // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.bazon_ok(p_bazon=>:p_bazon,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__bazon_ok__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__kedv_ellenor_6022__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  TYPE VARCHAR2_6_tab_typ IS TABLE OF VARCHAR2(6) INDEX BY BINARY_INTEGER;
  p_kedvezmenyek VARCHAR2_6_tab_typ := :1;
  v001 BRUNO.DB_WEB_ELEKTR.KEDVEZMENY_TAB_TYP;

BEGIN
  v001.DELETE;
  i1 := p_kedvezmenyek.FIRST;
  WHILE i1 IS NOT NULL LOOP
    v001(i1) := p_kedvezmenyek(i1);
    i1 := p_kedvezmenyek.NEXT(i1);
  END LOOP;

  DB_dealer.kedv_ellenor_6022(p_bazon=>:2,
		p_szerz_azon=>:3,
		p_kedvezmenyek=>v001,
		p_hiba_kod=>:4,
		p_hiba_szov=>:5);

  p_kedvezmenyek.DELETE;
  i1 := v001.FIRST;
  WHILE i1 IS NOT NULL LOOP
    p_kedvezmenyek(i1) := v001(i1);
    i1 := v001.NEXT(i1);
  END LOOP;
  :6 := p_kedvezmenyek;

END;
`

func (s *oracallServer) DbDealer_KedvEllenor_6022(ctx context.Context, input *DbDealer_KedvEllenor_6022_Input) (output *DbDealer_KedvEllenor_6022_Output, err error) {
	params := make([]interface{}, 6)
	var x, v interface{}
	_, _ = x, v
	params[1] = input.PBazon     // gcs2
	params[2] = input.PSzerzAzon // gcs2
	output.PKedvezmenyek = input.PKedvezmenyek
	params[0] = output.PKedvezmenyek // gcst1
	params[3] = output.PHibaKod      // gcs1
	params[4] = output.PHibaSzov     // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.kedv_ellenor_6022(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_kedvezmenyek=>v001,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__kedv_ellenor_6022__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__dealer_mod_uj__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.dealer_mod_uj(p_bazon=>:1,
		dealer_code=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4);


END;
`

func (s *oracallServer) DbDealer_DealerModUj(ctx context.Context, input *DbDealer_DealerModUj_Input) (output *DbDealer_DealerModUj_Output, err error) {
	params := make([]interface{}, 4)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.DealerCode // gcs2
	params[2] = output.PHibaKod  // gcs1
	params[3] = output.PHibaSzov // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.dealer_mod_uj(p_bazon=>:p_bazon,
		dealer_code=>:dealer_code,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__dealer_mod_uj__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__dealer_mod_torzsszam_letezik__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.dealer_mod_torzsszam_letezik(p_bazon=>:1,
		dealer_code=>:2,
		p_letezik=>:3,
		p_hiba_kod=>:4,
		p_hiba_szov=>:5);


END;
`

func (s *oracallServer) DbDealer_DealerModTorzsszamLetezik(ctx context.Context, input *DbDealer_DealerModTorzsszamLetezik_Input) (output *DbDealer_DealerModTorzsszamLetezik_Output, err error) {
	params := make([]interface{}, 5)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.DealerCode // gcs2
	params[2] = output.PLetezik  // gcs1
	params[3] = output.PHibaKod  // gcs1
	params[4] = output.PHibaSzov // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.dealer_mod_torzsszam_letezik(p_bazon=>:p_bazon,
		dealer_code=>:dealer_code,
		p_letezik=>:p_letezik,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__dealer_mod_torzsszam_letezik__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__dealer_mod_alap__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.dealer_mod_alap(p_bazon=>:1,
		dealer_code=>:2,
		p_modosit=>:3,
		dealer_name=>:4,
		dealer_sex=>:5,
		dealer_enter_date=>:6,
		dealer_exit_date=>:7,
		dealer_taxnumber_t=>:8,
		dealer_taxnumber_j=>:9,
		dealer_reg_code=>:10,
		dealer_bank_account=>:11,
		dealer_megye_jel=>:12,
		dealer_pszaf_kod=>:13,
		dealer_teljesitmeny_kod=>:14,
		p_hiba_kod=>:15,
		p_hiba_szov=>:16);


END;
`

func (s *oracallServer) DbDealer_DealerModAlap(ctx context.Context, input *DbDealer_DealerModAlap_Input) (output *DbDealer_DealerModAlap_Output, err error) {
	params := make([]interface{}, 16)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.DealerCode // gcs2
	params[2] = input.PModosit   // gcs2
	output.DealerName = input.DealerName
	params[3] = output.DealerName // gcs1
	output.DealerSex = input.DealerSex
	params[4] = output.DealerSex // gcs1
	output.DealerEnterDate = input.DealerEnterDate
	params[5] = output.DealerEnterDate // gcs1
	output.DealerExitDate = input.DealerExitDate
	params[6] = output.DealerExitDate // gcs1
	output.DealerTaxnumberT = input.DealerTaxnumberT
	params[7] = output.DealerTaxnumberT // gcs1
	output.DealerTaxnumberJ = input.DealerTaxnumberJ
	params[8] = output.DealerTaxnumberJ // gcs1
	output.DealerRegCode = input.DealerRegCode
	params[9] = output.DealerRegCode // gcs1
	output.DealerBankAccount = input.DealerBankAccount
	params[10] = output.DealerBankAccount // gcs1
	output.DealerMegyeJel = input.DealerMegyeJel
	params[11] = output.DealerMegyeJel // gcs1
	output.DealerPszafKod = input.DealerPszafKod
	params[12] = output.DealerPszafKod // gcs1
	output.DealerTeljesitmenyKod = input.DealerTeljesitmenyKod
	params[13] = output.DealerTeljesitmenyKod // gcs1
	params[14] = output.PHibaKod              // gcs1
	params[15] = output.PHibaSzov             // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.dealer_mod_alap(p_bazon=>:p_bazon,
		dealer_code=>:dealer_code,
		p_modosit=>:p_modosit,
		dealer_name=>:dealer_name,
		dealer_sex=>:dealer_sex,
		dealer_enter_date=>:dealer_enter_date,
		dealer_exit_date=>:dealer_exit_date,
		dealer_taxnumber_t=>:dealer_taxnumber_t,
		dealer_taxnumber_j=>:dealer_taxnumber_j,
		dealer_reg_code=>:dealer_reg_code,
		dealer_bank_account=>:dealer_bank_account,
		dealer_megye_jel=>:dealer_megye_jel,
		dealer_pszaf_kod=>:dealer_pszaf_kod,
		dealer_teljesitmeny_kod=>:dealer_teljesitmeny_kod,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__dealer_mod_alap__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__dealer_mod_cim__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.dealer_mod_cim(p_bazon=>:1,
		dealer_code=>:2,
		p_modosit=>:3,
		dealer_addr_pcode=>:4,
		dealer_addr_ppid=>:5,
		hazszam1=>:6,
		hazszam2=>:7,
		epulet=>:8,
		lepcsohaz=>:9,
		emelet=>:10,
		ajto=>:11,
		dealer_disp_name=>:12,
		dealer_disp_pcode=>:13,
		dealer_disp_addr=>:14,
		dealer_disp_phone=>:15,
		p_hiba_kod=>:16,
		p_hiba_szov=>:17);


END;
`

func (s *oracallServer) DbDealer_DealerModCim(ctx context.Context, input *DbDealer_DealerModCim_Input) (output *DbDealer_DealerModCim_Output, err error) {
	params := make([]interface{}, 17)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.DealerCode // gcs2
	params[2] = input.PModosit   // gcs2
	output.DealerAddrPcode = input.DealerAddrPcode
	params[3] = output.DealerAddrPcode // gcs1
	output.DealerAddrPpid = input.DealerAddrPpid
	params[4] = output.DealerAddrPpid // gcs1
	output.Hazszam1 = input.Hazszam1
	params[5] = output.Hazszam1 // gcs1
	output.Hazszam2 = input.Hazszam2
	params[6] = output.Hazszam2 // gcs1
	output.Epulet = input.Epulet
	params[7] = output.Epulet // gcs1
	output.Lepcsohaz = input.Lepcsohaz
	params[8] = output.Lepcsohaz // gcs1
	output.Emelet = input.Emelet
	params[9] = output.Emelet // gcs1
	output.Ajto = input.Ajto
	params[10] = output.Ajto // gcs1
	output.DealerDispName = input.DealerDispName
	params[11] = output.DealerDispName // gcs1
	output.DealerDispPcode = input.DealerDispPcode
	params[12] = output.DealerDispPcode // gcs1
	output.DealerDispAddr = input.DealerDispAddr
	params[13] = output.DealerDispAddr // gcs1
	output.DealerDispPhone = input.DealerDispPhone
	params[14] = output.DealerDispPhone // gcs1
	params[15] = output.PHibaKod        // gcs1
	params[16] = output.PHibaSzov       // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.dealer_mod_cim(p_bazon=>:p_bazon,
		dealer_code=>:dealer_code,
		p_modosit=>:p_modosit,
		dealer_addr_pcode=>:dealer_addr_pcode,
		dealer_addr_ppid=>:dealer_addr_ppid,
		hazszam1=>:hazszam1,
		hazszam2=>:hazszam2,
		epulet=>:epulet,
		lepcsohaz=>:lepcsohaz,
		emelet=>:emelet,
		ajto=>:ajto,
		dealer_disp_name=>:dealer_disp_name,
		dealer_disp_pcode=>:dealer_disp_pcode,
		dealer_disp_addr=>:dealer_disp_addr,
		dealer_disp_phone=>:dealer_disp_phone,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__dealer_mod_cim__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__dealer_mod_kapcsolat__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.dealer_mod_kapcsolat(p_bazon=>:1,
		dealer_code=>:2,
		p_modosit=>:3,
		dealer_email=>:4,
		dealer_phone_work=>:5,
		dealer_phone_mobile=>:6,
		p_hiba_kod=>:7,
		p_hiba_szov=>:8);


END;
`

func (s *oracallServer) DbDealer_DealerModKapcsolat(ctx context.Context, input *DbDealer_DealerModKapcsolat_Input) (output *DbDealer_DealerModKapcsolat_Output, err error) {
	params := make([]interface{}, 8)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.DealerCode // gcs2
	params[2] = input.PModosit   // gcs2
	output.DealerEmail = input.DealerEmail
	params[3] = output.DealerEmail // gcs1
	output.DealerPhoneWork = input.DealerPhoneWork
	params[4] = output.DealerPhoneWork // gcs1
	output.DealerPhoneMobile = input.DealerPhoneMobile
	params[5] = output.DealerPhoneMobile // gcs1
	params[6] = output.PHibaKod          // gcs1
	params[7] = output.PHibaSzov         // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.dealer_mod_kapcsolat(p_bazon=>:p_bazon,
		dealer_code=>:dealer_code,
		p_modosit=>:p_modosit,
		dealer_email=>:dealer_email,
		dealer_phone_work=>:dealer_phone_work,
		dealer_phone_mobile=>:dealer_phone_mobile,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__dealer_mod_kapcsolat__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__dealer_mod_hierarchia__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.dealer_mod_hierarchia(p_bazon=>:1,
		dealer_code=>:2,
		p_modosit=>:3,
		dealer_boss=>:4,
		dealer_job=>:5,
		p_hiba_kod=>:6,
		p_hiba_szov=>:7);


END;
`

func (s *oracallServer) DbDealer_DealerModHierarchia(ctx context.Context, input *DbDealer_DealerModHierarchia_Input) (output *DbDealer_DealerModHierarchia_Output, err error) {
	params := make([]interface{}, 7)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.DealerCode // gcs2
	params[2] = input.PModosit   // gcs2
	output.DealerBoss = input.DealerBoss
	params[3] = output.DealerBoss // gcs1
	output.DealerJob = input.DealerJob
	params[4] = output.DealerJob // gcs1
	params[5] = output.PHibaKod  // gcs1
	params[6] = output.PHibaSzov // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.dealer_mod_hierarchia(p_bazon=>:p_bazon,
		dealer_code=>:dealer_code,
		p_modosit=>:p_modosit,
		dealer_boss=>:dealer_boss,
		dealer_job=>:dealer_job,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__dealer_mod_hierarchia__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__dealer_mod_tevekenyseg__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.dealer_mod_tevekenyseg(p_bazon=>:1,
		dealer_code=>:2,
		p_modosit=>:3,
		dealer_hdijfiz_jog=>:4,
		p_hiba_kod=>:5,
		p_hiba_szov=>:6);


END;
`

func (s *oracallServer) DbDealer_DealerModTevekenyseg(ctx context.Context, input *DbDealer_DealerModTevekenyseg_Input) (output *DbDealer_DealerModTevekenyseg_Output, err error) {
	params := make([]interface{}, 6)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.DealerCode // gcs2
	params[2] = input.PModosit   // gcs2
	output.DealerHdijfizJog = input.DealerHdijfizJog
	params[3] = output.DealerHdijfizJog // gcs1
	params[4] = output.PHibaKod         // gcs1
	params[5] = output.PHibaSzov        // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.dealer_mod_tevekenyseg(p_bazon=>:p_bazon,
		dealer_code=>:dealer_code,
		p_modosit=>:p_modosit,
		dealer_hdijfiz_jog=>:dealer_hdijfiz_jog,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__dealer_mod_tevekenyseg__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__dealer_mod_vizsgak__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER_MODOS.VIZSGA_MOD_TAB_TYP;
  TYPE VARCHAR2_6_tab_typ IS TABLE OF VARCHAR2(6) INDEX BY BINARY_INTEGER;
  p002#modkod VARCHAR2_6_tab_typ;
  TYPE DATE_tab_typ IS TABLE OF DATE INDEX BY BINARY_INTEGER;
  p002#hatalytol DATE_tab_typ;
  p002#hatalyig DATE_tab_typ;
  v006 BRUNO.DB_DEALER_MODOS.CASCO_SZEMLE_REC_TYP;

BEGIN
  p002#modkod := :1;
  p002#hatalytol := :2;
  p002#hatalyig := :3;
  
  i1 := p002#hatalytol.FIRST;
  WHILE i1 IS NOT NULL LOOP
    v001(i1).hatalytol := p002#hatalytol(i1);
    v001(i1).hatalyig := p002#hatalyig(i1);
    v001(i1).modkod := p002#modkod(i1);
    i1 := p002#hatalytol.NEXT(i1);
  END LOOP;
  v006.osszeg := :4;
  v006.penznem := :5;
  v006.hatalytol := :6;
  v006.hatalyig := :7;

  DB_dealer.dealer_mod_vizsgak(p_bazon=>:8,
		dealer_code=>:9,
		p_modosit=>:10,
		dealer_exams=>v001,
		p_casco_szemle=>v006,
		p_hiba_kod=>:11,
		p_hiba_szov=>:12);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#hatalytol(i2) := v001(i1).hatalytol;
    p002#hatalyig(i2) := v001(i1).hatalyig;
    p002#modkod(i2) := v001(i1).modkod;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :13 := p002#hatalyig;
  :14 := p002#modkod;
  :15 := p002#hatalytol;
  :16 := v006.osszeg;
  :17 := v006.penznem;
  :18 := v006.hatalytol;
  :19 := v006.hatalyig;

END;
`

func (s *oracallServer) DbDealer_DealerModVizsgak(ctx context.Context, input *DbDealer_DealerModVizsgak_Input) (output *DbDealer_DealerModVizsgak_Output, err error) {
	params := make([]interface{}, 19)
	var x, v interface{}
	_, _ = x, v
	params[7] = input.PBazon     // gcs2
	params[8] = input.DealerCode // gcs2
	params[9] = input.PModosit   // gcs2

	x__DealerExams__Hatalytol := make([]custom.Date, 0, 1000)
	for i, v := range input.DealerExams {
		x__DealerExams__Hatalytol[i] = v.Hatalytol
	} // gctr1
	params[1] = x__DealerExams__Hatalytol

	x__DealerExams__Hatalyig := make([]custom.Date, 0, 1000)
	for i, v := range input.DealerExams {
		x__DealerExams__Hatalyig[i] = v.Hatalyig
	} // gctr1
	params[2] = x__DealerExams__Hatalyig

	x__DealerExams__Modkod := make([]string, 0, 1000)
	for i, v := range input.DealerExams {
		x__DealerExams__Modkod[i] = v.Modkod
	} // gctr1
	params[0] = x__DealerExams__Modkod

	output.PCascoSzemle = new(DbDealerModos_CascoSzemleRecTyp_Bruno)
	if input.PCascoSzemle != nil {
		*output.PCascoSzemle = *input.PCascoSzemle
	}

	if input.PCascoSzemle != nil {
		params[3] = input.PCascoSzemle.Osszeg
	} // gcr1
	params[15] = output.PCascoSzemle.Osszeg // gcr2
	if input.PCascoSzemle != nil {
		params[4] = input.PCascoSzemle.Penznem
	} // gcr1
	params[16] = output.PCascoSzemle.Penznem // gcr2
	if input.PCascoSzemle != nil {
		params[5] = input.PCascoSzemle.Hatalytol
	} // gcr1
	params[17] = output.PCascoSzemle.Hatalytol // gcr2
	if input.PCascoSzemle != nil {
		params[6] = input.PCascoSzemle.Hatalyig
	} // gcr1
	params[18] = output.PCascoSzemle.Hatalyig // gcr2
	params[10] = output.PHibaKod              // gcs1
	params[11] = output.PHibaSzov             // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.dealer_mod_vizsgak(p_bazon=>:p_bazon,
		dealer_code=>:dealer_code,
		p_modosit=>:p_modosit,
		dealer_exams=>v001,
		p_casco_szemle=>v006,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__dealer_mod_vizsgak__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.DealerExams == nil { // *Db_dealer_modos__vizsga_mod_rec_typ__bruno
		output.DealerExams = make([]*DbDealerModos_VizsgaModRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__DealerExams__Hatalytol) - cap(output.DealerExams); m > 0 {
		output.DealerExams = append(output.DealerExams, make([]*DbDealerModos_VizsgaModRecTyp_Bruno, m)...)
	}
	output.DealerExams = output.DealerExams[:len(x__DealerExams__Hatalytol)]
	for i, v := range x__DealerExams__Hatalytol {
		if output.DealerExams[i] != nil {
			output.DealerExams[i].Hatalytol = v
		}
	}
	if m := len(x__DealerExams__Hatalyig) - cap(output.DealerExams); m > 0 {
		output.DealerExams = append(output.DealerExams, make([]*DbDealerModos_VizsgaModRecTyp_Bruno, m)...)
	}
	output.DealerExams = output.DealerExams[:len(x__DealerExams__Hatalyig)]
	for i, v := range x__DealerExams__Hatalyig {
		if output.DealerExams[i] != nil {
			output.DealerExams[i].Hatalyig = v
		}
	}
	if m := len(x__DealerExams__Modkod) - cap(output.DealerExams); m > 0 {
		output.DealerExams = append(output.DealerExams, make([]*DbDealerModos_VizsgaModRecTyp_Bruno, m)...)
	}
	output.DealerExams = output.DealerExams[:len(x__DealerExams__Modkod)]
	for i, v := range x__DealerExams__Modkod {
		if output.DealerExams[i] != nil {
			output.DealerExams[i].Modkod = v
		}
	}

	return
}
const Db_dealer__pszaf_1565__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  DB_dealer.pszaf_1565(p_bazon=>:1,
		p_targyev=>:2,
		p_elo=>:3,
		p_darab=>:4,
		p_szumma=>:5,
		p_hiba_kod=>:6,
		p_hiba_szov=>:7);


END;
`

func (s *oracallServer) DbDealer_Pszaf_1565(ctx context.Context, input *DbDealer_Pszaf_1565_Input) (output *DbDealer_Pszaf_1565_Output, err error) {
	params := make([]interface{}, 7)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PTargyev   // gcs2
	params[2] = input.PElo       // gcs2
	params[3] = output.PDarab    // gcs1
	params[4] = output.PSzumma   // gcs1
	params[5] = output.PHibaKod  // gcs1
	params[6] = output.PHibaSzov // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.pszaf_1565(p_bazon=>:p_bazon,
		p_targyev=>:p_targyev,
		p_elo=>:p_elo,
		p_darab=>:p_darab,
		p_szumma=>:p_szumma,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__pszaf_1565__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__last_change__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;

BEGIN

  :1 := DB_dealer.last_change(p_tipus=>:2,
		p_hiba_kod=>:3,
		p_hiba_szov=>:4);


END;
`

func (s *oracallServer) DbDealer_LastChange(ctx context.Context, input *DbDealer_LastChange_Input) (output *DbDealer_LastChange_Output, err error) {
	params := make([]interface{}, 4)
	var x, v interface{}
	_, _ = x, v
	params[1] = input.PTipus     // gcs2
	params[2] = output.PHibaKod  // gcs1
	params[3] = output.PHibaSzov // gcs1
	params[0] = output.Ret       // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.last_change(p_tipus=>:p_tipus,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__last_change__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	return
}
const Db_dealer__tag_elvaras__plsql = `DECLARE
  i1 PLS_INTEGER;
  i2 PLS_INTEGER;
  v001 BRUNO.DB_DEALER.ELVARAS_TAB_TYP;
  TYPE NUMBER_12_2_tab_typ IS TABLE OF NUMBER(12, 2) INDEX BY BINARY_INTEGER;
  p002#elvaras NUMBER_12_2_tab_typ;
  p002#rendezve NUMBER_12_2_tab_typ;
  TYPE DATE_tab_typ IS TABLE OF DATE INDEX BY BINARY_INTEGER;
  p002#btkezd DATE_tab_typ;
  p002#elvi_kockvege DATE_tab_typ;
  TYPE NUMBER_9_tab_typ IS TABLE OF NUMBER(9) INDEX BY BINARY_INTEGER;
  p002#szerz_azon NUMBER_9_tab_typ;
  p002#tol DATE_tab_typ;
  p002#ig DATE_tab_typ;
  v010 BRUNO.DB_DEALER.TAGDIJ_BEF_TAB_TYP;
  p011#charge_paid_amount NUMBER_12_2_tab_typ;
  p011#charge_paid_date DATE_tab_typ;
  p011#charge_paid_credit_date DATE_tab_typ;
  p011#charge_paid_year_rel DATE_tab_typ;

BEGIN
  v001.DELETE;
  p002#elvaras.DELETE;
  p002#rendezve.DELETE;
  p002#btkezd.DELETE;
  p002#elvi_kockvege.DELETE;
  p002#szerz_azon.DELETE;
  p002#tol.DELETE;
  p002#ig.DELETE;
  v010.DELETE;
  p011#charge_paid_amount.DELETE;
  p011#charge_paid_date.DELETE;
  p011#charge_paid_credit_date.DELETE;
  p011#charge_paid_year_rel.DELETE;

  DB_dealer.tag_elvaras(p_bazon=>:1,
		p_szerz_azon=>:2,
		p_hataly=>:3,
		p_elvaras=>v001,
		p_tagdij_bef=>v010,
		p_hiba_kod=>:4,
		p_hiba_szov=>:5);

  
  i1 := v001.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p002#elvi_kockvege(i2) := v001(i1).elvi_kockvege;
    p002#szerz_azon(i2) := v001(i1).szerz_azon;
    p002#tol(i2) := v001(i1).tol;
    p002#ig(i2) := v001(i1).ig;
    p002#elvaras(i2) := v001(i1).elvaras;
    p002#rendezve(i2) := v001(i1).rendezve;
    p002#btkezd(i2) := v001(i1).btkezd;
    i1 := v001.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :6 := p002#elvaras;
  :7 := p002#rendezve;
  :8 := p002#btkezd;
  :9 := p002#elvi_kockvege;
  :10 := p002#szerz_azon;
  :11 := p002#tol;
  :12 := p002#ig;
  
  i1 := v010.FIRST; i2 := 1;
  WHILE i1 IS NOT NULL LOOP
    p011#charge_paid_year_rel(i2) := v010(i1).charge_paid_year_rel;
    p011#charge_paid_amount(i2) := v010(i1).charge_paid_amount;
    p011#charge_paid_date(i2) := v010(i1).charge_paid_date;
    p011#charge_paid_credit_date(i2) := v010(i1).charge_paid_credit_date;
    i1 := v010.NEXT(i1); i2 := i2 + 1;
  END LOOP;
  :13 := p011#charge_paid_date;
  :14 := p011#charge_paid_credit_date;
  :15 := p011#charge_paid_year_rel;
  :16 := p011#charge_paid_amount;

END;
`

func (s *oracallServer) DbDealer_TagElvaras(ctx context.Context, input *DbDealer_TagElvaras_Input) (output *DbDealer_TagElvaras_Output, err error) {
	params := make([]interface{}, 16)
	var x, v interface{}
	_, _ = x, v
	params[0] = input.PBazon     // gcs2
	params[1] = input.PSzerzAzon // gcs2
	params[2] = input.PHataly    // gcs2
	x__PElvaras__ElviKockvege := make([]custom.Date, 0, 1000)
	params[8] = x__PElvaras__ElviKockvege // gctr2
	x__PElvaras__SzerzAzon := make([]float64, 0, 1000)
	params[9] = x__PElvaras__SzerzAzon // gctr2
	x__PElvaras__Tol := make([]custom.Date, 0, 1000)
	params[10] = x__PElvaras__Tol // gctr2
	x__PElvaras__Ig := make([]custom.Date, 0, 1000)
	params[11] = x__PElvaras__Ig // gctr2
	x__PElvaras__Elvaras := make([]float64, 0, 1000)
	params[5] = x__PElvaras__Elvaras // gctr2
	x__PElvaras__Rendezve := make([]float64, 0, 1000)
	params[6] = x__PElvaras__Rendezve // gctr2
	x__PElvaras__Btkezd := make([]custom.Date, 0, 1000)
	params[7] = x__PElvaras__Btkezd // gctr2
	x__PTagdijBef__ChargePaidYearRel := make([]custom.Date, 0, 1000)
	params[14] = x__PTagdijBef__ChargePaidYearRel // gctr2
	x__PTagdijBef__ChargePaidAmount := make([]float64, 0, 1000)
	params[15] = x__PTagdijBef__ChargePaidAmount // gctr2
	x__PTagdijBef__ChargePaidDate := make([]custom.Date, 0, 1000)
	params[12] = x__PTagdijBef__ChargePaidDate // gctr2
	x__PTagdijBef__ChargePaidCreditDate := make([]custom.Date, 0, 1000)
	params[13] = x__PTagdijBef__ChargePaidCreditDate // gctr2
	params[3] = output.PHibaKod                      // gcs1
	params[4] = output.PHibaSzov                     // gcs1

	if true || DebugLevel > 0 {
		log.Printf(`calling DB_dealer.tag_elvaras(p_bazon=>:p_bazon,
		p_szerz_azon=>:p_szerz_azon,
		p_hataly=>:p_hataly,
		p_elvaras=>v001,
		p_tagdij_bef=>v010,
		p_hiba_kod=>:p_hiba_kod,
		p_hiba_szov=>:p_hiba_szov)
	with %s`, params)
	}
	ses, err := s.OraSesPool.Get()
	if err != nil {
		return nil, errors.Wrap(err, "Get")
	}
	defer s.OraSesPool.Put(ses)
	qry := Db_dealer__tag_elvaras__plsql
	if _, err = ses.PrepAndExeP(qry, params...); err != nil {
		return nil, errors.Wrapf(err, "%s %#v", qry, params)
	}

	if true || DebugLevel > 0 {
		log.Printf(`result params: %s`, params)
	}

	if output.PElvaras == nil { // *Db_dealer__elvaras_rec_typ__bruno
		output.PElvaras = make([]*DbDealer_ElvarasRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PElvaras__ElviKockvege) - cap(output.PElvaras); m > 0 {
		output.PElvaras = append(output.PElvaras, make([]*DbDealer_ElvarasRecTyp_Bruno, m)...)
	}
	output.PElvaras = output.PElvaras[:len(x__PElvaras__ElviKockvege)]
	for i, v := range x__PElvaras__ElviKockvege {
		if output.PElvaras[i] != nil {
			output.PElvaras[i].ElviKockvege = v
		}
	}
	if m := len(x__PElvaras__SzerzAzon) - cap(output.PElvaras); m > 0 {
		output.PElvaras = append(output.PElvaras, make([]*DbDealer_ElvarasRecTyp_Bruno, m)...)
	}
	output.PElvaras = output.PElvaras[:len(x__PElvaras__SzerzAzon)]
	for i, v := range x__PElvaras__SzerzAzon {
		if output.PElvaras[i] != nil {
			output.PElvaras[i].SzerzAzon = v
		}
	}
	if m := len(x__PElvaras__Tol) - cap(output.PElvaras); m > 0 {
		output.PElvaras = append(output.PElvaras, make([]*DbDealer_ElvarasRecTyp_Bruno, m)...)
	}
	output.PElvaras = output.PElvaras[:len(x__PElvaras__Tol)]
	for i, v := range x__PElvaras__Tol {
		if output.PElvaras[i] != nil {
			output.PElvaras[i].Tol = v
		}
	}
	if m := len(x__PElvaras__Ig) - cap(output.PElvaras); m > 0 {
		output.PElvaras = append(output.PElvaras, make([]*DbDealer_ElvarasRecTyp_Bruno, m)...)
	}
	output.PElvaras = output.PElvaras[:len(x__PElvaras__Ig)]
	for i, v := range x__PElvaras__Ig {
		if output.PElvaras[i] != nil {
			output.PElvaras[i].Ig = v
		}
	}
	if m := len(x__PElvaras__Elvaras) - cap(output.PElvaras); m > 0 {
		output.PElvaras = append(output.PElvaras, make([]*DbDealer_ElvarasRecTyp_Bruno, m)...)
	}
	output.PElvaras = output.PElvaras[:len(x__PElvaras__Elvaras)]
	for i, v := range x__PElvaras__Elvaras {
		if output.PElvaras[i] != nil {
			output.PElvaras[i].Elvaras = v
		}
	}
	if m := len(x__PElvaras__Rendezve) - cap(output.PElvaras); m > 0 {
		output.PElvaras = append(output.PElvaras, make([]*DbDealer_ElvarasRecTyp_Bruno, m)...)
	}
	output.PElvaras = output.PElvaras[:len(x__PElvaras__Rendezve)]
	for i, v := range x__PElvaras__Rendezve {
		if output.PElvaras[i] != nil {
			output.PElvaras[i].Rendezve = v
		}
	}
	if m := len(x__PElvaras__Btkezd) - cap(output.PElvaras); m > 0 {
		output.PElvaras = append(output.PElvaras, make([]*DbDealer_ElvarasRecTyp_Bruno, m)...)
	}
	output.PElvaras = output.PElvaras[:len(x__PElvaras__Btkezd)]
	for i, v := range x__PElvaras__Btkezd {
		if output.PElvaras[i] != nil {
			output.PElvaras[i].Btkezd = v
		}
	}

	if output.PTagdijBef == nil { // *Db_dealer__tagdij_bef_rec_typ__bruno
		output.PTagdijBef = make([]*DbDealer_TagdijBefRecTyp_Bruno, 0, 1000)
	}
	if m := len(x__PTagdijBef__ChargePaidYearRel) - cap(output.PTagdijBef); m > 0 {
		output.PTagdijBef = append(output.PTagdijBef, make([]*DbDealer_TagdijBefRecTyp_Bruno, m)...)
	}
	output.PTagdijBef = output.PTagdijBef[:len(x__PTagdijBef__ChargePaidYearRel)]
	for i, v := range x__PTagdijBef__ChargePaidYearRel {
		if output.PTagdijBef[i] != nil {
			output.PTagdijBef[i].ChargePaidYearRel = v
		}
	}
	if m := len(x__PTagdijBef__ChargePaidAmount) - cap(output.PTagdijBef); m > 0 {
		output.PTagdijBef = append(output.PTagdijBef, make([]*DbDealer_TagdijBefRecTyp_Bruno, m)...)
	}
	output.PTagdijBef = output.PTagdijBef[:len(x__PTagdijBef__ChargePaidAmount)]
	for i, v := range x__PTagdijBef__ChargePaidAmount {
		if output.PTagdijBef[i] != nil {
			output.PTagdijBef[i].ChargePaidAmount = v
		}
	}
	if m := len(x__PTagdijBef__ChargePaidDate) - cap(output.PTagdijBef); m > 0 {
		output.PTagdijBef = append(output.PTagdijBef, make([]*DbDealer_TagdijBefRecTyp_Bruno, m)...)
	}
	output.PTagdijBef = output.PTagdijBef[:len(x__PTagdijBef__ChargePaidDate)]
	for i, v := range x__PTagdijBef__ChargePaidDate {
		if output.PTagdijBef[i] != nil {
			output.PTagdijBef[i].ChargePaidDate = v
		}
	}
	if m := len(x__PTagdijBef__ChargePaidCreditDate) - cap(output.PTagdijBef); m > 0 {
		output.PTagdijBef = append(output.PTagdijBef, make([]*DbDealer_TagdijBefRecTyp_Bruno, m)...)
	}
	output.PTagdijBef = output.PTagdijBef[:len(x__PTagdijBef__ChargePaidCreditDate)]
	for i, v := range x__PTagdijBef__ChargePaidCreditDate {
		if output.PTagdijBef[i] != nil {
			output.PTagdijBef[i].ChargePaidCreditDate = v
		}
	}

	return
}
func init() {
}
